@@ -197,6 +197,22 @@ int AB_Account_ReadDb(AB_ACCOUNT *a, GWEN_DB_NODE *db){
     snprintf(numbuf, sizeof(numbuf)-1, "%u", id);
     GWEN_StringList_AppendString(a->selectedUserIds, numbuf, 0, 1);
   }
+  /* fix problem where there is no userId in the list */
+  if (GWEN_StringList_Count(a->userIds)<GWEN_StringList_Count(a->selectedUserIds)) {
+    GWEN_STRINGLISTENTRY *se;
+  
+    se=GWEN_StringList_FirstEntry(a->selectedUserIds);
+    while(se) {
+      const char *s;
+  
+      s=GWEN_StringListEntry_Data(se);
+      if (s) {
+	GWEN_StringList_AppendString(a->userIds, s, 0, 1);
+      }
+
+      se=GWEN_StringListEntry_Next(se);
+    }
+  }
 
   /* TODO: START: remove this */
   GWEN_DB_Group_free(a->appData);
@@ -304,6 +320,35 @@ AB_USER *AB_Account_GetFirstUser(const AB_ACCOUNT *a) {
 
 
 
+int AB_Account_HasUser(const AB_ACCOUNT *a, uint32_t uid) {
+  GWEN_STRINGLISTENTRY *se;
+
+  assert(a);
+  assert(a->usage);
+
+  se=GWEN_StringList_FirstEntry(a->userIds);
+  while(se) {
+    const char *s;
+
+    s=GWEN_StringListEntry_Data(se);
+    if (s) {
+      unsigned int id;
+
+      if (1==sscanf(s, "%u", &id)) {
+        if (id==uid)
+          return 0;
+      }
+    }
+
+    se=GWEN_StringListEntry_Next(se);
+  }
+
+  DBG_INFO(AQBANKING_LOGDOMAIN, "User with id \"%u\" not found", uid);
+  return GWEN_ERROR_NOT_FOUND;
+}
+
+
+
 void AB_Account_SetUsers(AB_ACCOUNT *a, const AB_USER_LIST2 *ul) {
   assert(a);
   assert(a->usage);
@@ -425,6 +470,35 @@ AB_USER *AB_Account_GetFirstSelectedUser(const AB_ACCOUNT *a) {
 
 
 
+int AB_Account_HasSelectedUser(const AB_ACCOUNT *a, uint32_t uid) {
+  GWEN_STRINGLISTENTRY *se;
+
+  assert(a);
+  assert(a->usage);
+
+  se=GWEN_StringList_FirstEntry(a->selectedUserIds);
+  while(se) {
+    const char *s;
+
+    s=GWEN_StringListEntry_Data(se);
+    if (s) {
+      unsigned int id;
+
+      if (1==sscanf(s, "%u", &id)) {
+        if (id==uid)
+          return 0;
+      }
+    }
+
+    se=GWEN_StringListEntry_Next(se);
+  }
+
+  DBG_INFO(AQBANKING_LOGDOMAIN, "User with id \"%u\" not found", uid);
+  return GWEN_ERROR_NOT_FOUND;
+}
+
+
+
 void AB_Account_SetSelectedUsers(AB_ACCOUNT *a, const AB_USER_LIST2 *ul) {
   assert(a);
   assert(a->usage);
@@ -445,6 +519,7 @@ void AB_Account_SetSelectedUsers(AB_ACCOUNT *a, const AB_USER_LIST2 *ul) {
 	snprintf(numbuf, sizeof(numbuf)-1, "%u", AB_User_GetUniqueId(u));
         numbuf[sizeof(numbuf)-1]=0;
 	GWEN_StringList_AppendString(a->selectedUserIds, numbuf, 0, 1);
+	GWEN_StringList_AppendString(a->userIds, numbuf, 0, 1); /* also add to userIds, if not already done */
 	u=AB_User_List2Iterator_Next(it);
       }
       AB_User_List2Iterator_free(it);
@@ -465,6 +540,7 @@ void AB_Account_SetSelectedUser(AB_ACCOUNT *a, const AB_USER *u) {
 
     snprintf(numbuf, sizeof(numbuf)-1, "%u", AB_User_GetUniqueId(u));
     GWEN_StringList_AppendString(a->selectedUserIds, numbuf, 0, 1);
+    GWEN_StringList_AppendString(a->userIds, numbuf, 0, 1); /* also add to userIds, if not already done */
   }
 }
 
@@ -929,6 +1005,27 @@ void AB_Account_List2_FreeAll(AB_ACCOUNT_LIST2 *al){
 
 
 
+AB_ACCOUNT *AB_Account_List2_GetAccountByUniqueId(const AB_ACCOUNT_LIST2 *al, uint32_t aid) {
+  AB_ACCOUNT_LIST2_ITERATOR *ait;
+
+  ait=AB_Account_List2_First(al);
+  if (ait) {
+    AB_ACCOUNT *a;
+
+    a=AB_Account_List2Iterator_Data(ait);
+    assert(a);
+    while(a) {
+      if (aid==AB_Account_GetUniqueId(a)) {
+        AB_Account_List2Iterator_free(ait);
+        return a;
+      }
+      a=AB_Account_List2Iterator_Next(ait);
+    }
+    AB_Account_List2Iterator_free(ait);
+  }
+
+  return NULL;
+}
 
 
 
