@@ -47,8 +47,14 @@ GWEN_LIST2_FUNCTION_LIB_DEFS(AB_ACCOUNT, AB_Account, AQBANKING_API)
 /* Do not terminate these lines with semicolon because they are
    macros, not functions, and ISO C89 does not allow a semicolon
    there. */
+
+AQBANKING_API
 void AB_Account_List2_FreeAll(AB_ACCOUNT_LIST2 *al);
 
+AQBANKING_API
+AB_ACCOUNT *AB_Account_List2_GetAccountByUniqueId(const AB_ACCOUNT_LIST2 *al, uint32_t aid);
+
+
 typedef enum {
   AB_AccountType_Unknown=0,
   AB_AccountType_Bank,
@@ -57,7 +63,9 @@ typedef enum {
   AB_AccountType_Savings,
   AB_AccountType_Investment,
   AB_AccountType_Cash,
-  AB_AccountType_MoneyMarket
+  AB_AccountType_MoneyMarket,
+  AB_AccountType_Credit,
+  AB_AccountType_Last
 } AB_ACCOUNT_TYPE;
 
 #ifdef __cplusplus
@@ -173,6 +181,9 @@ AB_USER_LIST2 *AB_Account_GetUsers(const AB_ACCOUNT *acc);
 AQBANKING_API
 AB_USER *AB_Account_GetFirstUser(const AB_ACCOUNT *acc);
 
+AQBANKING_API
+int AB_Account_HasUser(const AB_ACCOUNT *a, uint32_t uid);
+
 AQBANKING_API
 void AB_Account_SetUsers(AB_ACCOUNT *acc, const AB_USER_LIST2 *ul);
 
@@ -186,6 +197,9 @@ AB_USER_LIST2 *AB_Account_GetSelectedUsers(const AB_ACCOUNT *acc);
 AQBANKING_API
 AB_USER *AB_Account_GetFirstSelectedUser(const AB_ACCOUNT *acc);
 
+AQBANKING_API
+int AB_Account_HasSelectedUser(const AB_ACCOUNT *a, uint32_t uid);
+
 AQBANKING_API
 void AB_Account_SetSelectedUsers(AB_ACCOUNT *acc, const AB_USER_LIST2 *ul);
 
@@ -193,6 +207,8 @@ AQBANKING_API
 void AB_Account_SetSelectedUser(AB_ACCOUNT *a, const AB_USER *u);
 
 
+
+
 #ifdef __cplusplus
 }
 #endif
