@@ -192,8 +192,7 @@ void AB_Plugin_BankInfo_FreeData(void *bp, void *p) {
 
 
 AB_BANKINFO_PLUGIN *AB_Plugin_BankInfo_Factory(GWEN_PLUGIN *pl,
-					       AB_BANKING *ab,
-					       GWEN_DB_NODE *db) {
+					       AB_BANKING *ab) {
   AB_PLUGIN_BANKINFO *xpl;
 
   assert(pl);
@@ -201,7 +200,7 @@ AB_BANKINFO_PLUGIN *AB_Plugin_BankInfo_Factory(GWEN_PLUGIN *pl,
   assert(xpl);
 
   assert(xpl->pluginFactoryFn);
-  return xpl->pluginFactoryFn(pl, ab, db);
+  return xpl->pluginFactoryFn(pl, ab);
 }
 
 
