@@ -1,13 +1,14 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: banking_info.h 953 2006-02-24 03:07:59Z aquamaniac $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
- *          Please see toplevel file COPYING for license details           *
+ * This file is part of the project "AqBanking".                           *
+ * Please see toplevel file COPYING of that project for license details.   *
  ***************************************************************************/
 
 
@@ -101,6 +102,13 @@ AB_Banking_CheckAccount(AB_BANKING *ab,
 AQBANKING_API
 int AB_Banking_CheckIban(const char *iban);
 
+
+/**
+ * Create an IBAN from German bank code and account number.
+ */
+AQBANKING_API
+int AB_Banking_MakeGermanIban(const char *bankCode, const char *accountNumber, GWEN_BUFFER *ibanBuf);
+
 /*@}*/
 
 
