@@ -198,7 +198,7 @@ AB_USER *AB_Banking_CreateUser(AB_BANKING *ab, const char *backendName) {
 
   u=AB_User_new(ab);
   AB_User_SetBackendName(u, AB_Provider_GetName(pro));
-  uid=AB_Banking_GetUniqueId(ab, 0);
+  uid=AB_Banking_GetUniqueId(ab);
   assert(uid);
   AB_User_SetUniqueId(u, uid);
   rv=AB_Provider_ExtendUser(pro, u, AB_ProviderExtendMode_Create, NULL);
@@ -262,8 +262,7 @@ int AB_Banking_AddUser(AB_BANKING *ab, AB_USER *u) {
 
   rv=GWEN_ConfigMgr_GetUniqueId(ab->configMgr,
 				AB_CFG_GROUP_USERS,
-				groupName, sizeof(groupName)-1,
-				0);
+				groupName, sizeof(groupName)-1);
   if (rv<0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN,
 	      "Unable to create a unique id for user [%08x] (%d)",
@@ -275,8 +274,7 @@ int AB_Banking_AddUser(AB_BANKING *ab, AB_USER *u) {
 
   rv=GWEN_ConfigMgr_LockGroup(ab->configMgr,
 			      AB_CFG_GROUP_USERS,
-			      groupName,
-			      0);
+			      groupName);
   if (rv<0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN,
 	      "Unable to lock user config [%08x] (%d)",
@@ -288,8 +286,7 @@ int AB_Banking_AddUser(AB_BANKING *ab, AB_USER *u) {
   rv=GWEN_ConfigMgr_SetGroup(ab->configMgr,
 			     AB_CFG_GROUP_USERS,
 			     groupName,
-			     db,
-			     0);
+			     db);
   GWEN_DB_Group_free(db);
   if (rv<0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN,
@@ -297,16 +294,14 @@ int AB_Banking_AddUser(AB_BANKING *ab, AB_USER *u) {
 	      AB_User_GetUniqueId(u), rv);
     GWEN_ConfigMgr_UnlockGroup(ab->configMgr,
 			       AB_CFG_GROUP_USERS,
-			       groupName,
-			       0);
+			       groupName);
     return rv;
   }
 
   /* unlock */
   rv=GWEN_ConfigMgr_UnlockGroup(ab->configMgr,
 				AB_CFG_GROUP_USERS,
-				groupName,
-				0);
+				groupName);
   if (rv<0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN,
 	      "Unable to unlock user config [%08x] (%d)",
@@ -387,8 +382,7 @@ int AB_Banking_DeleteUser(AB_BANKING *ab, AB_USER *u) {
   if (groupName) {
     rv=GWEN_ConfigMgr_DeleteGroup(ab->configMgr,
 				  AB_CFG_GROUP_USERS,
-				  groupName,
-				  0);
+				  groupName);
     if (rv<0) {
       DBG_ERROR(AQBANKING_LOGDOMAIN,
 		"Unable to delete user config [%08x] (%d)",
