@@ -55,7 +55,7 @@ GWEN_DIALOG *AB_EditAccountDialog_new(AB_BANKING *ab, AB_ACCOUNT *a, int doLock)
 
   /* get path of dialog description file */
   fbuf=GWEN_Buffer_new(0, 256, 0, 1);
-  rv=GWEN_PathManager_FindFile(GWEN_PM_LIBNAME, GWEN_PM_SYSDATADIR,
+  rv=GWEN_PathManager_FindFile(AB_PM_LIBNAME, AB_PM_DATADIR,
 			       "aqbanking/dialogs/dlg_editaccount.dlg",
 			       fbuf);
   if (rv<0) {
@@ -376,18 +376,13 @@ void AB_EditAccountDialog_RebuildUserLists(GWEN_DIALOG *dlg) {
       u1=AB_User_List2Iterator_Data(it1);
       while(u1) {
 	createUserString(u1, tbuf);
-	GWEN_Dialog_SetCharProperty(dlg,
-				    "userCombo",
-				    GWEN_DialogProperty_AddValue,
-				    0,
-				    GWEN_Buffer_GetStart(tbuf),
-				    0);
+	GWEN_StringList_AppendString(sl, GWEN_Buffer_GetStart(tbuf), 0, 1);
 	GWEN_Buffer_Reset(tbuf);
 	u1=AB_User_List2Iterator_Next(it1);
       }
       AB_User_List2Iterator_free(it1);
     }
-    GWEN_Buffer_Reset(tbuf);
+    GWEN_Buffer_free(tbuf);
   }
   AB_User_List2_free(users);
 
@@ -481,7 +476,7 @@ void AB_EditAccountDialog_Init(GWEN_DIALOG *dlg) {
       GWEN_Buffer_free(tbuf);
       AB_Country_ConstList2Iterator_free(it);
 
-      GWEN_StringList_Sort(sl, 0, GWEN_StringList_SortModeNoCase);
+      GWEN_StringList_Sort(sl, 1, GWEN_StringList_SortModeNoCase);
       idx=-1;
       i=0;
       se=GWEN_StringList_FirstEntry(sl);
@@ -543,7 +538,7 @@ void AB_EditAccountDialog_Init(GWEN_DIALOG *dlg) {
       GWEN_Buffer_free(tbuf);
       AB_Country_ConstList2Iterator_free(it);
 
-      GWEN_StringList_Sort(sl, 0, GWEN_StringList_SortModeNoCase);
+      GWEN_StringList_Sort(sl, 1, GWEN_StringList_SortModeNoCase);
       idx=-1;
       i=0;
       se=GWEN_StringList_FirstEntry(sl);
