@@ -53,7 +53,7 @@ GWEN_DIALOG *AB_EditUserDialog_new(AB_BANKING *ab, AB_USER *u, int doLock) {
 
   /* get path of dialog description file */
   fbuf=GWEN_Buffer_new(0, 256, 0, 1);
-  rv=GWEN_PathManager_FindFile(GWEN_PM_LIBNAME, GWEN_PM_SYSDATADIR,
+  rv=GWEN_PathManager_FindFile(AB_PM_LIBNAME, AB_PM_DATADIR,
 			       "aqbanking/dialogs/dlg_edituser.dlg",
 			       fbuf);
   if (rv<0) {
@@ -219,7 +219,7 @@ void AB_EditUserDialog_Init(GWEN_DIALOG *dlg) {
       GWEN_Buffer_free(tbuf);
       AB_Country_ConstList2Iterator_free(it);
 
-      GWEN_StringList_Sort(sl, 0, GWEN_StringList_SortModeNoCase);
+      GWEN_StringList_Sort(sl, 1, GWEN_StringList_SortModeNoCase);
       idx=-1;
       i=0;
       se=GWEN_StringList_FirstEntry(sl);
