@@ -35,6 +35,8 @@ GWEN_GUI *AB_Gui_new(AB_BANKING *ab) {
 
   xgui->banking=ab;
   xgui->checkCertFn=GWEN_Gui_SetCheckCertFn(gui, AB_Gui_CheckCert);
+  xgui->readDialogPrefsFn=GWEN_Gui_SetReadDialogPrefsFn(gui, AB_Gui_ReadDialogPrefs);
+  xgui->writeDialogPrefsFn=GWEN_Gui_SetWriteDialogPrefsFn(gui, AB_Gui_WriteDialogPrefs);
 
   return gui;
 }
@@ -50,6 +52,8 @@ void AB_Gui_Extend(GWEN_GUI *gui, AB_BANKING *ab) {
 
   xgui->banking=ab;
   xgui->checkCertFn=GWEN_Gui_SetCheckCertFn(gui, AB_Gui_CheckCert);
+  GWEN_Gui_SetReadDialogPrefsFn(gui, AB_Gui_ReadDialogPrefs);
+  GWEN_Gui_SetWriteDialogPrefsFn(gui, AB_Gui_WriteDialogPrefs);
 }
 
 
@@ -65,12 +69,15 @@ void AB_Gui_Unextend(GWEN_GUI *gui) {
   GWEN_Gui_SetCheckCertFn(gui, xgui->checkCertFn);
 
   /* unlink from GWEN_GUI object */
+  DBG_INFO(AQBANKING_LOGDOMAIN, "Unlinking GUI from banking object");
+  GWEN_Gui_SetReadDialogPrefsFn(gui, xgui->readDialogPrefsFn);
+  GWEN_Gui_SetWriteDialogPrefsFn(gui, xgui->writeDialogPrefsFn);
   GWEN_INHERIT_UNLINK(GWEN_GUI, AB_GUI, gui);
 }
 
 
 
-void AB_Gui_FreeData(void *bp, void *p) {
+void GWENHYWFAR_CB AB_Gui_FreeData(void *bp, void *p) {
   AB_GUI *xgui;
 
   xgui=(AB_GUI*) p;
@@ -114,7 +121,7 @@ int AB_Gui__HashPair(const char *token,
 
 int AB_Gui_CheckCert(GWEN_GUI *gui,
 		     const GWEN_SSLCERTDESCR *cd,
-		     GWEN_IO_LAYER *io, uint32_t guiid) {
+		     GWEN_SYNCIO *sio, uint32_t guiid) {
   AB_GUI *xgui;
   const char *hash;
   const char *status;
@@ -134,17 +141,17 @@ int AB_Gui_CheckCert(GWEN_GUI *gui,
   AB_Gui__HashPair(hash, status, hbuf);
 
   /* lock certificate data */
-  rv=AB_Banking_LockSharedConfig(xgui->banking, "certs", guiid);
+  rv=AB_Banking_LockSharedConfig(xgui->banking, "certs");
   if (rv<0) {
     /* fallback */
     DBG_WARN(AQBANKING_LOGDOMAIN, "Could not lock certs db, asking user (%d)", rv);
-    result=xgui->checkCertFn(gui, cd, io, guiid);
+    result=xgui->checkCertFn(gui, cd, sio, guiid);
   }
   else {
     int i;
 
     /* load certificate data */
-    rv=AB_Banking_LoadSharedConfig(xgui->banking, "certs", &dbCerts, guiid);
+    rv=AB_Banking_LoadSharedConfig(xgui->banking, "certs", &dbCerts);
     if (rv<0) {
       DBG_INFO(AQBANKING_LOGDOMAIN, "Could not load certs (%d)", rv);
       dbCerts=GWEN_DB_Group_new("certs");
@@ -174,6 +181,7 @@ int AB_Gui_CheckCert(GWEN_GUI *gui,
 		       "Automatically accepting valid new certificate [%s]",
 		       hash);
 	    GWEN_Buffer_free(hbuf);
+	    AB_Banking_UnlockSharedConfig(xgui->banking, "certs");
 	    return 0;
 	  }
 	  else {
@@ -181,6 +189,7 @@ int AB_Gui_CheckCert(GWEN_GUI *gui,
 		       "Automatically rejecting certificate [%s] (noninteractive)",
 		       hash);
 	    GWEN_Buffer_free(hbuf);
+	    AB_Banking_UnlockSharedConfig(xgui->banking, "certs");
 	    return GWEN_ERROR_USER_ABORTED;
 	  }
 	} /* if cert is valid */
@@ -190,13 +199,14 @@ int AB_Gui_CheckCert(GWEN_GUI *gui,
 		       "Automatically rejecting invalid certificate [%s] (noninteractive)",
 		       hash);
 	    GWEN_Buffer_free(hbuf);
+	    AB_Banking_UnlockSharedConfig(xgui->banking, "certs");
 	    return GWEN_ERROR_USER_ABORTED;
 	  }
 	}
       } /* if non-interactive */
 
       if (xgui->checkCertFn) {
-	result=xgui->checkCertFn(gui, cd, io, guiid);
+	result=xgui->checkCertFn(gui, cd, sio, guiid);
 	if (result==0) {
 	  GWEN_DB_SetIntValue(dbCerts, GWEN_DB_FLAGS_OVERWRITE_VARS,
 			      GWEN_Buffer_GetStart(hbuf), result);
@@ -206,14 +216,14 @@ int AB_Gui_CheckCert(GWEN_GUI *gui,
 
     /* write new certs */
     DBG_DEBUG(AQBANKING_LOGDOMAIN, "Saving certs");
-    rv=AB_Banking_SaveSharedConfig(xgui->banking, "certs", dbCerts, guiid);
+    rv=AB_Banking_SaveSharedConfig(xgui->banking, "certs", dbCerts);
     if (rv<0) {
-      DBG_WARN(AQBANKING_LOGDOMAIN, "Could not unlock certs db (%d)", rv);
+      DBG_WARN(AQBANKING_LOGDOMAIN, "Could not write certs db (%d)", rv);
     }
 
     /* unlock certs */
     DBG_DEBUG(AQBANKING_LOGDOMAIN, "Unlocking certs");
-    rv=AB_Banking_UnlockSharedConfig(xgui->banking, "certs", guiid);
+    rv=AB_Banking_UnlockSharedConfig(xgui->banking, "certs");
     if (rv<0) {
       DBG_NOTICE(AQBANKING_LOGDOMAIN, "Could not unlock certs db (%d)", rv);
     }
@@ -227,3 +237,98 @@ int AB_Gui_CheckCert(GWEN_GUI *gui,
 }
 
 
+
+int AB_Gui_ReadDialogPrefs(GWEN_GUI *gui,
+			   const char *groupName,
+			   const char *altName,
+			   GWEN_DB_NODE **pDb) {
+  AB_GUI *xgui;
+
+  assert(gui);
+  xgui=GWEN_INHERIT_GETDATA(GWEN_GUI, AB_GUI, gui);
+  assert(xgui);
+
+  if (groupName && *groupName) {
+    int rv;
+    const char *s;
+    GWEN_DB_NODE *db;
+    GWEN_BUFFER *nbuf;
+
+    nbuf=GWEN_Buffer_new(0, 64, 0, 1);
+    s=GWEN_Gui_GetName();
+    if (s && *s) {
+      GWEN_Buffer_AppendString(nbuf, s);
+      GWEN_Buffer_AppendString(nbuf, "_");
+    }
+    GWEN_Buffer_AppendString(nbuf, groupName);
+
+    rv=AB_Banking_LoadSharedConfig(xgui->banking,
+                                   GWEN_Buffer_GetStart(nbuf),
+				   &db);
+    if (rv<0) {
+      DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+      GWEN_Buffer_free(nbuf);
+      return rv;
+    }
+    *pDb=db;
+    GWEN_Buffer_free(nbuf);
+    return 0;
+  }
+  else {
+    DBG_ERROR(AQBANKING_LOGDOMAIN, "No groupName");
+    return GWEN_ERROR_NO_DATA;
+  }
+}
+
+
+
+int AB_Gui_WriteDialogPrefs(GWEN_GUI *gui,
+			    const char *groupName,
+			    GWEN_DB_NODE *db) {
+  AB_GUI *xgui;
+
+  assert(gui);
+  xgui=GWEN_INHERIT_GETDATA(GWEN_GUI, AB_GUI, gui);
+  assert(xgui);
+
+  if (groupName && *groupName && db) {
+    int rv;
+    const char *s;
+    GWEN_BUFFER *nbuf;
+
+    nbuf=GWEN_Buffer_new(0, 64, 0, 1);
+    s=GWEN_Gui_GetName();
+    if (s && *s) {
+      GWEN_Buffer_AppendString(nbuf, s);
+      GWEN_Buffer_AppendString(nbuf, "_");
+    }
+    GWEN_Buffer_AppendString(nbuf, groupName);
+
+    /* lock configuration */
+    rv=AB_Banking_LockSharedConfig(xgui->banking,
+                                   GWEN_Buffer_GetStart(nbuf));
+    if (rv==0) {
+      /* save configuration */
+      rv=AB_Banking_SaveSharedConfig(xgui->banking,
+				     GWEN_Buffer_GetStart(nbuf),
+				     db);
+      if (rv<0) {
+	DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+      }
+
+      /* unlock configuration */
+      rv=AB_Banking_UnlockSharedConfig(xgui->banking,
+				       GWEN_Buffer_GetStart(nbuf));
+      if (rv<0) {
+	DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+      }
+    }
+    GWEN_Buffer_free(nbuf);
+  }
+
+  return 0;
+}
+
+
+
+
