@@ -33,14 +33,14 @@ static int AB_Gui_CheckCert(GWEN_GUI *gui,
 			    const GWEN_SSLCERTDESCR *cd,
 			    GWEN_SYNCIO *sio, uint32_t guiid);
 
-static int AB_Gui_WriteDialogPrefs(GWEN_GUI *gui,
-				   const char *groupName,
-				   GWEN_DB_NODE *db);
+static int GWENHYWFAR_CB AB_Gui_WriteDialogPrefs(GWEN_GUI *gui,
+                                                 const char *groupName,
+                                                 GWEN_DB_NODE *db);
 
-static int AB_Gui_ReadDialogPrefs(GWEN_GUI *gui,
-				  const char *groupName,
-				  const char *altName,
-				  GWEN_DB_NODE **pDb);
+static int GWENHYWFAR_CB AB_Gui_ReadDialogPrefs(GWEN_GUI *gui,
+                                                const char *groupName,
+                                                const char *altName,
+                                                GWEN_DB_NODE **pDb);
 
 
 
