@@ -322,6 +322,16 @@ AB_ImExporterContext_FindAccountInfo(AB_IMEXPORTER_CONTEXT *iec,
 				     const char *bankCode,
 				     const char *accountNumber);
 
+/**
+ * Looks for account info for the given account. If it is not found 0 is
+ * returned.
+ * This is for SEPA.
+ * The context remains the owner of the returned object.
+ */
+AQBANKING_API 
+AB_IMEXPORTER_ACCOUNTINFO*
+AB_ImExporterContext_FindAccountInfoByIban(AB_IMEXPORTER_CONTEXT *iec, const char *iban);
+
 /**
  * Looks for account info for the given account. If there is none it will
  * be created and added to the context.
@@ -333,6 +343,17 @@ AB_ImExporterContext_GetAccountInfo(AB_IMEXPORTER_CONTEXT *iec,
                                     const char *bankCode,
                                     const char *accountNumber);
 
+/**
+ * Looks for account info for the given account. If there is none it will
+ * be created and added to the context.
+ * This function is for SEPA.
+ * The context remains the owner of the returned object.
+ */
+AQBANKING_API
+AB_IMEXPORTER_ACCOUNTINFO*
+AB_ImExporterContext_GetAccountInfoByIban(AB_IMEXPORTER_CONTEXT *iec, const char *iban);
+
+
 AQBANKING_API
 int AB_ImExporterContext_GetAccountInfoCount(const AB_IMEXPORTER_CONTEXT *iec);
 
@@ -681,6 +702,36 @@ void AB_ImExporterAccountInfo_ClearTransactions(AB_IMEXPORTER_ACCOUNTINFO *iea);
 /*@}*/
 
 
+/** @name Security
+ *
+ */
+/*@{*/
+/**
+ * Takes over ownership of the given security.
+ */
+AQBANKING_API 
+void AB_ImExporterAccountInfo_AddSecurity(AB_IMEXPORTER_ACCOUNTINFO *iea,
+                                               AB_SECURITY *sec);
+/**
+ * Returns the first security stored within the context and removes
+ * it.
+ * The context remains the owner of the object returned.
+ */
+AQBANKING_API 
+AB_SECURITY*
+AB_ImExporterAccountInfo_GetFirstSecurity(AB_IMEXPORTER_ACCOUNTINFO *iea);
+
+/**
+ * Returns the next security stored within the context and removes it
+ * The context remains the owner of the object returned.
+ */
+AQBANKING_API 
+AB_SECURITY*
+AB_ImExporterAccountInfo_GetNextSecurity(AB_IMEXPORTER_ACCOUNTINFO *iea);
+
+/*@}*/
+
+
 /** @name Account Status
  *
  */
@@ -1000,6 +1051,9 @@ GWEN_TIME *AB_ImExporter_DateFromString(const char *p,
                                         int inUtc);
 
 
+AQBANKING_API 
+int AB_ImExporterContext_WriteContext(const AB_IMEXPORTER_CONTEXT *ctx, const char *ctxFile);
+
 /*@}*/
 
 
