@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Mon Mar 01 2004
- copyright   : (C) 2004 by Martin Preuss
+ copyright   : (C) 2004-2013 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -25,7 +22,6 @@
 #include "jobs/jobgettransactions_l.h"
 #include "jobs/jobgetstandingorders_l.h"
 #include "jobs/jobgetbalance_l.h"
-#include "jobs/jobtransferbase_l.h"
 #include "jobs/jobsingletransfer_l.h"
 #include "jobs/jobsingledebitnote_l.h"
 #include "jobs/jobeutransfer_l.h"
@@ -83,6 +79,8 @@ AB_JOB *AB_Job_new(AB_JOB_TYPE jt, AB_ACCOUNT *a){
   if (!bankCode || !*bankCode)
     bankCode="[no bankcode]";
   accountNumber=AB_Account_GetAccountNumber(a);
+  if (!accountNumber || !*accountNumber)
+    accountNumber="[no account number]";
 
   lbuf=GWEN_Buffer_new(0, 32, 0, 1);
   GWEN_Buffer_AppendString(lbuf, "Created job for account \"");
@@ -129,8 +127,11 @@ void AB_Job_free(AB_JOB *j){
       DBG_VERBOUS(AQBANKING_LOGDOMAIN, "Destroying AB_JOB");
       GWEN_INHERIT_FINI(AB_JOB, j);
       GWEN_LIST_FINI(AB_JOB, j);
+      AB_Transaction_free(j->transaction);
+      AB_TransactionLimits_free(j->limits);
       AB_Account_free(j->account);
       GWEN_DB_Group_free(j->dbData);
+      GWEN_Time_free(j->lastStatusChange);
       free(j->resultText);
       free(j->createdBy);
       free(j->usedTan);
@@ -242,23 +243,28 @@ const char *AB_Job_Type2Char(AB_JOB_TYPE i) {
   const char *s;
 
   switch(i) {
-  case AB_Job_TypeGetBalance:          s="getbalance"; break;
-  case AB_Job_TypeGetTransactions:     s="gettransactions"; break;
-  case AB_Job_TypeTransfer:            s="transfer"; break;
-  case AB_Job_TypeDebitNote:           s="debitnote"; break;
-  case AB_Job_TypeEuTransfer:          s="eutransfer"; break;
-  case AB_Job_TypeGetStandingOrders:   s="getstandingorders"; break;
-  case AB_Job_TypeGetDatedTransfers:   s="getdatedtransfers"; break;
-  case AB_Job_TypeCreateStandingOrder: s="createstandingorder"; break;
-  case AB_Job_TypeModifyStandingOrder: s="modifystandingorder"; break;
-  case AB_Job_TypeDeleteStandingOrder: s="deletestandingorder"; break;
-  case AB_Job_TypeCreateDatedTransfer: s="createdatedtransfer"; break;
-  case AB_Job_TypeModifyDatedTransfer: s="modifydatedtransfer"; break;
-  case AB_Job_TypeDeleteDatedTransfer: s="deletedatedtransfer"; break;
-  case AB_Job_TypeInternalTransfer:    s="internaltransfer"; break;
-  case AB_Job_TypeLoadCellPhone:       s="loadCellPhone"; break;
-  case AB_Job_TypeSepaTransfer:        s="sepaTransfer"; break;
-  case AB_Job_TypeSepaDebitNote:       s="sepaDebitNote"; break;
+  case AB_Job_TypeGetBalance:              s="getbalance"; break;
+  case AB_Job_TypeGetTransactions:         s="gettransactions"; break;
+  case AB_Job_TypeTransfer:                s="transfer"; break;
+  case AB_Job_TypeDebitNote:               s="debitnote"; break;
+  case AB_Job_TypeEuTransfer:              s="eutransfer"; break;
+  case AB_Job_TypeGetStandingOrders:       s="getstandingorders"; break;
+  case AB_Job_TypeGetDatedTransfers:       s="getdatedtransfers"; break;
+  case AB_Job_TypeCreateStandingOrder:     s="createstandingorder"; break;
+  case AB_Job_TypeModifyStandingOrder:     s="modifystandingorder"; break;
+  case AB_Job_TypeDeleteStandingOrder:     s="deletestandingorder"; break;
+  case AB_Job_TypeCreateDatedTransfer:     s="createdatedtransfer"; break;
+  case AB_Job_TypeModifyDatedTransfer:     s="modifydatedtransfer"; break;
+  case AB_Job_TypeDeleteDatedTransfer:     s="deletedatedtransfer"; break;
+  case AB_Job_TypeInternalTransfer:        s="internaltransfer"; break;
+  case AB_Job_TypeLoadCellPhone:           s="loadCellPhone"; break;
+  case AB_Job_TypeSepaTransfer:            s="sepaTransfer"; break;
+  case AB_Job_TypeSepaDebitNote:           s="sepaDebitNote"; break;
+  case AB_Job_TypeSepaCreateStandingOrder: s="sepaCreateStandingOrder"; break;
+  case AB_Job_TypeSepaModifyStandingOrder: s="sepaModifyStandingOrder"; break;
+  case AB_Job_TypeSepaDeleteStandingOrder: s="sepaDeleteStandingOrder"; break;
+  case AB_Job_TypeSepaFlashDebitNote:      s="sepaFlashDebitNote"; break;
+  case AB_Job_TypeSepaGetStandingOrders:   s="sepaGetStandingOrders"; break;
   default:
   case AB_Job_TypeUnknown:             s="unknown"; break;
   }
@@ -272,23 +278,29 @@ const char *AB_Job_Type2LocalChar(AB_JOB_TYPE i) {
   const char *s;
 
   switch(i) {
-  case AB_Job_TypeGetBalance:          s=I18N("Get Balance"); break;
-  case AB_Job_TypeGetTransactions:     s=I18N("Get Transactions"); break;
-  case AB_Job_TypeTransfer:            s=I18N("Transfer"); break;
-  case AB_Job_TypeDebitNote:           s=I18N("Debit Note"); break;
-  case AB_Job_TypeEuTransfer:          s=I18N("EU Transfer"); break;
-  case AB_Job_TypeGetStandingOrders:   s=I18N("Get Standing Orders"); break;
-  case AB_Job_TypeGetDatedTransfers:   s=I18N("Get Dated Transfers"); break;
-  case AB_Job_TypeCreateStandingOrder: s=I18N("Create Standing Order"); break;
-  case AB_Job_TypeModifyStandingOrder: s=I18N("Modify Standing Order"); break;
-  case AB_Job_TypeDeleteStandingOrder: s=I18N("Delete Standing Order"); break;
-  case AB_Job_TypeCreateDatedTransfer: s=I18N("Create Dated Transfer"); break;
-  case AB_Job_TypeModifyDatedTransfer: s=I18N("Modify Dated Transfer"); break;
-  case AB_Job_TypeDeleteDatedTransfer: s=I18N("Delete Dated Transfer"); break;
-  case AB_Job_TypeInternalTransfer:    s=I18N("Internal Transfer"); break;
-  case AB_Job_TypeLoadCellPhone:       s=I18N("Load Cellphone"); break;
-  case AB_Job_TypeSepaTransfer:        s=I18N("SEPA Transfer"); break;
-  case AB_Job_TypeSepaDebitNote:       s=I18N("SEPA Debit Note"); break;
+  case AB_Job_TypeGetBalance:              s=I18N("Get Balance"); break;
+  case AB_Job_TypeGetTransactions:         s=I18N("Get Transactions"); break;
+  case AB_Job_TypeTransfer:                s=I18N("Transfer"); break;
+  case AB_Job_TypeDebitNote:               s=I18N("Debit Note"); break;
+  case AB_Job_TypeEuTransfer:              s=I18N("EU Transfer"); break;
+  case AB_Job_TypeGetStandingOrders:       s=I18N("Get Standing Orders"); break;
+  case AB_Job_TypeGetDatedTransfers:       s=I18N("Get Dated Transfers"); break;
+  case AB_Job_TypeCreateStandingOrder:     s=I18N("Create Standing Order"); break;
+  case AB_Job_TypeModifyStandingOrder:     s=I18N("Modify Standing Order"); break;
+  case AB_Job_TypeDeleteStandingOrder:     s=I18N("Delete Standing Order"); break;
+  case AB_Job_TypeCreateDatedTransfer:     s=I18N("Create Dated Transfer"); break;
+  case AB_Job_TypeModifyDatedTransfer:     s=I18N("Modify Dated Transfer"); break;
+  case AB_Job_TypeDeleteDatedTransfer:     s=I18N("Delete Dated Transfer"); break;
+  case AB_Job_TypeInternalTransfer:        s=I18N("Internal Transfer"); break;
+  case AB_Job_TypeLoadCellPhone:           s=I18N("Load Cellphone"); break;
+  case AB_Job_TypeSepaTransfer:            s=I18N("SEPA Transfer"); break;
+  case AB_Job_TypeSepaDebitNote:           s=I18N("SEPA Debit Note"); break;
+
+  case AB_Job_TypeSepaCreateStandingOrder: s=I18N("SEPA Create Standing Order"); break;
+  case AB_Job_TypeSepaModifyStandingOrder: s=I18N("SEPA Modify Standing Order"); break;
+  case AB_Job_TypeSepaDeleteStandingOrder: s=I18N("SEPA Delete Standing Order"); break;
+  case AB_Job_TypeSepaFlashDebitNote:      s=I18N("SEPA Flash Debit Note"); break;
+  case AB_Job_TypeSepaGetStandingOrders:   s=I18N("SEPA Get Standing Orders"); break;
   default:
   case AB_Job_TypeUnknown:             s=I18N("unknown"); break;
   }
@@ -534,6 +546,59 @@ GWEN_STRINGLIST *AB_Job_GetLogs(const AB_JOB *j) {
 
 
 
+int AB_Job_SetTransaction(AB_JOB *j, const AB_TRANSACTION *t) {
+  assert(j);
+  if (t) {
+    AB_TRANSACTION *cpy;
+    AB_ACCOUNT *a;
+    AB_BANKING *ba;
+
+    cpy=AB_Transaction_dup(t);
+
+    a=AB_Job_GetAccount(j);
+    assert(a);
+    ba=AB_Account_GetBanking(a);
+    assert(ba);
+
+    AB_Transaction_free(j->transaction);
+    j->transaction=cpy;
+    /* assign unique id */
+    AB_Transaction_SetUniqueId(j->transaction, AB_Banking_GetUniqueId(ba));
+  }
+  else {
+    AB_Transaction_free(j->transaction);
+    j->transaction=NULL;
+  }
+
+  return 0;
+}
+
+
+
+AB_TRANSACTION *AB_Job_GetTransaction(const AB_JOB *j) {
+  assert(j);
+  return j->transaction;
+}
+
+
+
+const AB_TRANSACTION_LIMITS *AB_Job_GetFieldLimits(AB_JOB *j) {
+  assert(j);
+  return j->limits;
+}
+
+
+
+void AB_Job_SetFieldLimits(AB_JOB *j, AB_TRANSACTION_LIMITS *limits) {
+  assert(j);
+
+  AB_TransactionLimits_free(j->limits);
+  if (limits) j->limits=AB_TransactionLimits_dup(limits);
+  else j->limits=0;
+}
+
+
+
 void AB_Job_DateToDb(const GWEN_TIME *ti, GWEN_DB_NODE *db, const char *name){
   if (ti) {
     GWEN_BUFFER *dbuf;
