@@ -1,13 +1,11 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id: jobmodifysto_l.h 937 2006-02-14 02:44:12Z aquamaniac $
  begin       : Mon Mar 01 2004
- copyright   : (C) 2004 by Martin Preuss
+ copyright   : (C) 2004-2013 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
- *          Please see toplevel file COPYING for license details           *
+ * This file is part of the project "AqBanking".                           *
+ * Please see toplevel file COPYING of that project for license details.   *
  ***************************************************************************/
 
 
