@@ -1,13 +1,11 @@
 /***************************************************************************
- $RCSfile: jobsingletransfer_be.h,v $
- -------------------
- cvs         : $Id: jobsingletransfer_be.h,v 1.6 2006/02/21 17:04:54 aquamaniac Exp $
  begin       : Mon Mar 01 2004
- copyright   : (C) 2004 by Martin Preuss
+ copyright   : (C) 2004-2013 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
- *          Please see toplevel file COPYING for license details           *
+ * This file is part of the project "AqBanking".                           *
+ * Please see toplevel file COPYING of that project for license details.   *
  ***************************************************************************/
 
 
@@ -33,7 +31,7 @@
  * This function lets the backend specify the limits for some of the fields
  * of a @ref AB_TRANSACTION.
  */
-AQBANKING_API
+AQBANKING_API AQBANKING_DEPRECATED
 void AB_JobSingleTransfer_SetFieldLimits(AB_JOB *j,
                                          AB_TRANSACTION_LIMITS *limits);
 /*@}*/ 
