@@ -54,7 +54,7 @@ AH_JOB *AH_Job_GetKeys_new(AB_USER *u){
   int version;
 
   assert(u);
-  j=AH_Job_new("JobGetKeys", u, 0, 0, 0);
+  j=AH_Job_new("JobGetKeys", u, 0, 0);
   if (!j) {
     DBG_ERROR(AQHBCI_LOGDOMAIN,
               "JobGetKeys not supported, should not happen");
@@ -351,9 +351,9 @@ AH_JOB *AH_Job_SendKeys_new(AB_USER *u,
   assert(u);
 
   if (authKeyInfo)
-    j=AH_Job_new("JobSendKeysWithAuthKey", u, 0, 0, 0);
+    j=AH_Job_new("JobSendKeysWithAuthKey", u, 0, 0);
   else
-    j=AH_Job_new("JobSendKeys", u, 0, 0, 0);
+    j=AH_Job_new("JobSendKeys", u, 0, 0);
   if (!j) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "JobSendKeys not supported, should not happen");
     return NULL;
@@ -597,7 +597,7 @@ AH_JOB *AH_Job_UpdateBank_new(AB_USER *u) {
   AH_JOB_UPDATEBANK *jd;
 
   assert(u);
-  j=AH_Job_new("JobUpdateBankInfo", u, 0, 0, 0);
+  j=AH_Job_new("JobUpdateBankInfo", u, 0, 0);
   if (!j) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "JobUpdateBankInfo not supported, should not happen");
     return 0;
@@ -647,6 +647,9 @@ int AH_Job_UpdateBank_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
   jd=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_UPDATEBANK, j);
   assert(jd);
 
+  /* This function is just for informational purposes, the real account handling is done in
+   * AH_Job_CommitSystemData() */
+
   if (jd->scanned)
     return 0;
 
@@ -663,60 +666,25 @@ int AH_Job_UpdateBank_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
 
   /* search for "AccountData" */
   accs=0;
-  dbCurr=GWEN_DB_GetFirstGroup(dbResponses);
+  dbCurr=GWEN_DB_FindFirstGroup(dbResponses, "AccountData");
   while(dbCurr) {
-    dbAccountData=GWEN_DB_GetGroup(dbCurr, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
-				   "data/AccountData2");
-    if (dbAccountData==NULL)
-      dbAccountData=GWEN_DB_GetGroup(dbCurr, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
-				     "data/AccountData");
+    dbAccountData=GWEN_DB_GetGroup(dbCurr, GWEN_PATH_FLAGS_NAMEMUSTEXIST, "data/AccountData");
     if (dbAccountData) {
-      const char *accountId;
-      const char *userName;
-      const char *accountName;
-      const char *bankCode;
-      const char *accountSuffix;
       AB_ACCOUNT *acc;
-  
-      DBG_INFO(AQHBCI_LOGDOMAIN, "Found an account candidate");
 
-      /* account data found */
-      accountId=GWEN_DB_GetCharValue(dbAccountData, "accountId", 0, 0);
-      accountSuffix=GWEN_DB_GetCharValue(dbAccountData, "accountsubid", 0, 0);
-      accountName=GWEN_DB_GetCharValue(dbAccountData, "account/name", 0, 0);
-      userName=GWEN_DB_GetCharValue(dbAccountData, "name1", 0, 0);
-      bankCode=GWEN_DB_GetCharValue(dbAccountData, "bankCode", 0, 0);
+      DBG_INFO(AQHBCI_LOGDOMAIN, "Found an account");
 
-      if (accountId && *accountId &&
-	  bankCode && *bankCode) {
-	acc=AB_Banking_CreateAccount(ab, AH_PROVIDER_NAME);
-	assert(acc);
-        if (strcasecmp(GWEN_DB_GroupName(dbAccountData), "AccountData2")==0)
-          /* KTV in version 2 available */
-          AH_Account_AddFlags(acc, AH_BANK_FLAGS_KTV2);
-        else
-          AH_Account_SubFlags(acc, AH_BANK_FLAGS_KTV2);
-	AB_Account_SetBankCode(acc, bankCode);
-	AB_Account_SetAccountNumber(acc, accountId);
+      acc=AB_Banking_CreateAccount(ab, AH_PROVIDER_NAME);
+      assert(acc);
+      /* AB_Banking_CreateAccount() already assigns a unique id, we don't want that just yet */
+      AB_Account_SetUniqueId(acc, 0);
 
-	if (accountName)
-	  AB_Account_SetAccountName(acc, accountName);
-        if (accountSuffix)
-          AB_Account_SetSubAccountId(acc, accountSuffix);
-        if (userName)
-	  AB_Account_SetOwnerName(acc, userName);
+      AH_Job_ReadAccountDataSeg(acc, dbAccountData);
 
-        accs++;
-	AB_Account_List2_PushBack(jd->accountList, acc);
-      }
-      else {
-	DBG_ERROR(AQHBCI_LOGDOMAIN, "Missing information in account: BLZ=[%s], Kto=[%s], AccName=[%s]",
-		  bankCode?bankCode:"",
-		  accountId?accountId:"",
-		  accountName?accountName:"");
-      }
+      accs++;
+      AB_Account_List2_PushBack(jd->accountList, acc);
     }
-    dbCurr=GWEN_DB_GetNextGroup(dbCurr);
+    dbCurr=GWEN_DB_FindNextGroup(dbCurr, "AccountData");
   }
   if (!accs) {
     DBG_WARN(AQHBCI_LOGDOMAIN, "No accounts found");
@@ -771,7 +739,7 @@ AH_JOB *AH_Job_GetSysId_new(AB_USER *u){
   AH_JOB_GETSYSID *jd;
 
   assert(u);
-  j=AH_Job_new("JobSync", u, 0, 0, 0);
+  j=AH_Job_new("JobSync", u, 0, 0);
   if (!j) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "JobSync not supported, should not happen");
     return 0;
@@ -930,9 +898,9 @@ AH_JOB *AH_Job_TestVersion_new(AB_USER *u, int anon){
 
   assert(u);
   if (anon)
-    j=AH_Job_new("JobDialogInitAnon", u, 0, 0, 0);
+    j=AH_Job_new("JobDialogInitAnon", u, 0, 0);
   else
-    j=AH_Job_new("JobDialogInit", u, 0, 0, 0);
+    j=AH_Job_new("JobDialogInit", u, 0, 0);
   if (!j) {
     DBG_ERROR(AQHBCI_LOGDOMAIN,
               "JobTestVersion not supported, should not happen");
@@ -1082,7 +1050,7 @@ AH_JOB *AH_Job_GetStatus_new(AB_USER *u,
   AH_JOB_GETSTATUS *aj;
   GWEN_DB_NODE *dbArgs;
 
-  j=AH_Job_new("JobGetStatus", u, 0, 0, 0);
+  j=AH_Job_new("JobGetStatus", u, 0, 0);
   if (!j)
     return 0;
 
@@ -1197,7 +1165,7 @@ AH_JOB *AH_Job_Tan_new(AB_USER *u, int process, int jobVersion) {
   const char *s;
 
   DBG_INFO(AQHBCI_LOGDOMAIN, "Looking for TAN job in version %d", jobVersion);
-  j=AH_Job_new("JobTan", u, 0, 0, jobVersion);
+  j=AH_Job_new("JobTan", u, 0, jobVersion);
   if (!j) {
     DBG_INFO(AQHBCI_LOGDOMAIN, "TAN job in version %d not found", jobVersion);
     return NULL;
@@ -1681,7 +1649,7 @@ AH_JOB *AH_Job_GetItanModes_new(AB_USER *u){
   AH_JOB_GETITANMODES *jd;
 
   assert(u);
-  j=AH_Job_new("JobGetItanModes", u, 0, 0, 0);
+  j=AH_Job_new("JobGetItanModes", u, 0, 0);
   if (!j) {
     DBG_ERROR(AQHBCI_LOGDOMAIN,
               "JobGetItanModes not supported, should not happen");
@@ -1813,7 +1781,7 @@ AH_JOB *AH_Job_ChangePin_new(AB_USER *u, const char *newPin){
   GWEN_DB_NODE *dbArgs;
 
   assert(u);
-  j=AH_Job_new("JobChangePin", u, 0, 0, 0);
+  j=AH_Job_new("JobChangePin", u, 0, 0);
   if (!j) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "JobChangePin not supported, should not happen");
     return 0;
@@ -1857,7 +1825,7 @@ AH_JOB *AH_Job_GetAccountSepaInfo_new(AB_USER *u, AB_ACCOUNT *acc) {
   const char *s;
 
   assert(u);
-  j=AH_Job_new("JobGetAccountSepaInfo", u, 0, 0, 0);
+  j=AH_Job_new("JobGetAccountSepaInfo", u, 0, 0);
   if (!j) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "JobGetAccountSepaInfo not supported, should not happen");
     return 0;
@@ -1960,68 +1928,116 @@ int AH_Job_GetAccountSepaInfo_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
     dbXA=GWEN_DB_GetGroup(dbCurr, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
                           "data/GetAccountSepaInfoResponse");
     if (dbXA) {
+      GWEN_DB_NODE *dbAccount;
       const char *accountId;
       const char *bankCode;
       const char *accountSuffix;
-      const char *iban;
-      const char *bic;
       const char *sSepa;
-      int useWithSepa=0;
 
-      /* account data found */
-      DBG_INFO(AQHBCI_LOGDOMAIN, "Found a GetAccountSepaInfoResponse segment");
-      accountId=GWEN_DB_GetCharValue(dbXA, "accountId", 0, 0);
-      accountSuffix=GWEN_DB_GetCharValue(dbXA, "accountsubid", 0, 0);
-      bankCode=GWEN_DB_GetCharValue(dbXA, "bankCode", 0, 0);
-      sSepa=GWEN_DB_GetCharValue(dbXA, "sepa", 0, "n");
-      if (strcasecmp(sSepa, "j")==0)
-        useWithSepa=1;
+      dbAccount=GWEN_DB_FindFirstGroup(dbXA, "account");
+      if (dbAccount) {
+        /* there is account info, are there multiple accounts returned? */
+        if (NULL!=GWEN_DB_FindNextGroup(dbAccount, "account")) {
+          const char *reqAccountId;
+          const char *reqBankCode;
+          const char *reqAccountSuffix;
 
-      iban=GWEN_DB_GetCharValue(dbXA, "iban", 0, 0);
-      bic=GWEN_DB_GetCharValue(dbXA, "bic", 0, 0);
+          /* yes, multiple accounts, find the one we requested */
+          DBG_INFO(AQHBCI_LOGDOMAIN, "Multiple accounts returned in GetAccountSepaInfoResponse");
+          /* GWEN_DB_Dump(dbXA, 2); */
 
-      rv=AB_Banking_BeginExclUseAccount(ab, jd->account);
-      if (rv<0) {
-        DBG_ERROR(AQHBCI_LOGDOMAIN, "Unable to lock account");
-      }
-      else {
-        if (accountSuffix)
-          AB_Account_SetSubAccountId(jd->account, accountSuffix);
-        AH_Account_AddFlags(jd->account, AH_BANK_FLAGS_KTV2); /* we have a sub id (even if emtpy), set flag */
+          reqAccountId=AB_Account_GetAccountNumber(jd->account);
+          reqBankCode=AB_Account_GetBankCode(jd->account);
+          reqAccountSuffix=AB_Account_GetSubAccountId(jd->account);
+          if (reqAccountSuffix==NULL)
+            reqAccountSuffix="";
 
-	if (useWithSepa) {
-	  DBG_INFO(AQHBCI_LOGDOMAIN, "SEPA available with this account");
-	  AH_Account_AddFlags(jd->account, AH_BANK_FLAGS_SEPA); /* we have a sub id (even if emtpy), set flag */
-	}
-	else {
-	  DBG_INFO(AQHBCI_LOGDOMAIN, "SEPA not available with this account");
-	  AH_Account_SubFlags(jd->account, AH_BANK_FLAGS_SEPA); /* we have a sub id (even if emtpy), set flag */
-	}
+          while(dbAccount) {
+            accountId=GWEN_DB_GetCharValue(dbAccount, "accountId", 0, 0);
+            accountSuffix=GWEN_DB_GetCharValue(dbAccount, "accountsubid", 0, 0);
+            if (accountSuffix==NULL)
+              accountSuffix="";
+            bankCode=GWEN_DB_GetCharValue(dbAccount, "bankCode", 0, 0);
+            sSepa=GWEN_DB_GetCharValue(dbAccount, "sepa", 0, "n");
 
-        if (iban && *iban) {
-	  if (bic && *bic) {
-	    DBG_NOTICE(AQHBCI_LOGDOMAIN, "Setting IBAN and BIC: %s/%s", iban, bic);
-	    AB_Account_SetIBAN(jd->account, iban);
-	    AB_Account_SetBIC(jd->account, bic);
-	  }
-	  else {
-	    DBG_NOTICE(AQHBCI_LOGDOMAIN, "Setting IBAN (no BIC): %s", iban);
-	    AB_Account_SetIBAN(jd->account, iban);
-	  }
+            DBG_DEBUG(AQHBCI_LOGDOMAIN,
+                      "- checking this account: bc=%s, an=%s, as=%s, sepa=%s (searching bc=%s, an=%s, as=%s)",
+                      bankCode, accountId, accountSuffix, sSepa,
+                      reqBankCode, reqAccountId, reqAccountSuffix);
+            if (
+                (bankCode && reqBankCode && 0==strcasecmp(bankCode, reqBankCode)) &&
+                (accountId && reqAccountId && 0==strcasecmp(accountId, reqAccountId)) &&
+                (accountSuffix && reqAccountSuffix && 0==strcasecmp(accountSuffix, reqAccountSuffix)) &&
+                (strcasecmp(sSepa, "j")==0)
+               ) {
+              /* matching account found, break */
+              DBG_INFO(AQHBCI_LOGDOMAIN, "Found matching account in GetAccountSepaInfoResponse");
+              break;
+            }
+            dbAccount=GWEN_DB_FindNextGroup(dbAccount, "account");
+          } /* while */
         }
-        else {
-          DBG_ERROR(AQHBCI_LOGDOMAIN, "Missing information in account: BLZ=[%s], Kto=[%s], IBAN=[%s], BIC=[%s]",
-                    bankCode?bankCode:"",
-                    accountId?accountId:"",
-                    iban?iban:"",
-                    bic?bic:"");
-        }
-        AB_Banking_EndExclUseAccount(ab, jd->account, 0);
-      }
-    }
 
+        if (dbAccount) {
+          const char *iban;
+          const char *bic;
+          int useWithSepa=0;
+
+          /* account data found */
+          DBG_INFO(AQHBCI_LOGDOMAIN, "Found a GetAccountSepaInfoResponse segment");
+          accountId=GWEN_DB_GetCharValue(dbAccount, "accountId", 0, 0);
+          accountSuffix=GWEN_DB_GetCharValue(dbAccount, "accountsubid", 0, 0);
+          bankCode=GWEN_DB_GetCharValue(dbAccount, "bankCode", 0, 0);
+          sSepa=GWEN_DB_GetCharValue(dbAccount, "sepa", 0, "n");
+          if (strcasecmp(sSepa, "j")==0)
+            useWithSepa=1;
+
+          iban=GWEN_DB_GetCharValue(dbAccount, "iban", 0, 0);
+          bic=GWEN_DB_GetCharValue(dbAccount, "bic", 0, 0);
+
+          rv=AB_Banking_BeginExclUseAccount(ab, jd->account);
+          if (rv<0) {
+            DBG_ERROR(AQHBCI_LOGDOMAIN, "Unable to lock account");
+          }
+          else {
+            if (accountSuffix)
+              AB_Account_SetSubAccountId(jd->account, accountSuffix);
+            AH_Account_AddFlags(jd->account, AH_BANK_FLAGS_KTV2); /* we have a sub id (even if emtpy), set flag */
+
+            if (useWithSepa) {
+              DBG_INFO(AQHBCI_LOGDOMAIN, "SEPA available with this account");
+              AH_Account_AddFlags(jd->account, AH_BANK_FLAGS_SEPA); /* we have a sub id (even if emtpy), set flag */
+            }
+            else {
+              DBG_INFO(AQHBCI_LOGDOMAIN, "SEPA not available with this account");
+              AH_Account_SubFlags(jd->account, AH_BANK_FLAGS_SEPA); /* we have a sub id (even if emtpy), set flag */
+            }
+
+            if (iban && *iban) {
+              if (bic && *bic) {
+                DBG_NOTICE(AQHBCI_LOGDOMAIN, "Setting IBAN and BIC: %s/%s", iban, bic);
+                AB_Account_SetIBAN(jd->account, iban);
+                AB_Account_SetBIC(jd->account, bic);
+              }
+              else {
+                DBG_NOTICE(AQHBCI_LOGDOMAIN, "Setting IBAN (no BIC): %s", iban);
+                AB_Account_SetIBAN(jd->account, iban);
+              }
+            }
+            else {
+              DBG_ERROR(AQHBCI_LOGDOMAIN, "Missing information in account: BLZ=[%s], Kto=[%s], IBAN=[%s], BIC=[%s]",
+                        bankCode?bankCode:"",
+                        accountId?accountId:"",
+                        iban?iban:"",
+                        bic?bic:"");
+            }
+            AB_Banking_EndExclUseAccount(ab, jd->account, 0);
+          }
+        }
+      } /* if dbAccount */
+    } /* if (dbXA) */
     dbCurr=GWEN_DB_GetNextGroup(dbCurr);
-  }
+  } /* while dbCurr */
 
   return 0;
 }
