@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004 by Martin Preuss
+    copyright   : (C) 2004-2014 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -27,6 +24,8 @@ typedef struct AH_OUTBOX AH_OUTBOX;
 
 #include <aqbanking/imexporter.h>
 #include <gwenhywfar/inherit.h>
+#include <gwenhywfar/gwentime.h>
+
 #include "hbci_l.h"
 #include "job_l.h"
 #include <aqhbci/user.h>
@@ -66,7 +65,7 @@ int AH_Outbox_Execute(AH_OUTBOX *ob,
 AH_JOB *AH_Outbox_FindTransferJob(AH_OUTBOX *ob,
                                   AB_USER *u,
                                   AB_ACCOUNT *a,
-                                  int isTransfer);
+                                  const char *jobName);
 
 
 AH_JOB_LIST *AH_Outbox_GetFinishedJobs(AH_OUTBOX *ob);
