@@ -277,10 +277,18 @@ void AH_PinTanSpecialDialog_Init(GWEN_DIALOG *dlg) {
 			     (xdlg->flags & AH_USER_FLAGS_FORCE_SSL3)?1:0,
 			     0);
 
+  GWEN_Dialog_SetIntProperty(dlg, "ignorePrematureCloseCheck", GWEN_DialogProperty_Value, 0,
+                             (xdlg->flags & AH_USER_FLAGS_TLS_IGN_PREMATURE_CLOSE)?1:0,
+			     0);
+
   GWEN_Dialog_SetIntProperty(dlg, "noBase64Check", GWEN_DialogProperty_Value, 0,
 			     (xdlg->flags & AH_USER_FLAGS_NO_BASE64)?1:0,
 			     0);
 
+  GWEN_Dialog_SetIntProperty(dlg, "omitSmsAccountCheck", GWEN_DialogProperty_Value, 0,
+			     (xdlg->flags & AH_USER_FLAGS_TAN_OMIT_SMS_ACCOUNT)?1:0,
+			     0);
+
   if (xdlg->tanMediumId)
     GWEN_Dialog_SetCharProperty(dlg, "tanMediumIdEdit", GWEN_DialogProperty_Value, 0, xdlg->tanMediumId, 0);
   /* set tooltip */
@@ -340,8 +348,12 @@ void AH_PinTanSpecialDialog_Fini(GWEN_DIALOG *dlg) {
   flags=0;
   if (GWEN_Dialog_GetIntProperty(dlg, "forceSslv3Check", GWEN_DialogProperty_Value, 0, 0))
     flags|=AH_USER_FLAGS_FORCE_SSL3;
+  if (GWEN_Dialog_GetIntProperty(dlg, "ignorePrematureCloseCheck", GWEN_DialogProperty_Value, 0, 0))
+    flags|=AH_USER_FLAGS_TLS_IGN_PREMATURE_CLOSE;
   if (GWEN_Dialog_GetIntProperty(dlg, "noBase64Check", GWEN_DialogProperty_Value, 0, 0))
     flags|=AH_USER_FLAGS_NO_BASE64;
+  if (GWEN_Dialog_GetIntProperty(dlg, "omitSmsAccountCheck", GWEN_DialogProperty_Value, 0, 0))
+    flags|=AH_USER_FLAGS_TAN_OMIT_SMS_ACCOUNT;
   xdlg->flags=flags;
 
   s=GWEN_Dialog_GetCharProperty(dlg, "tanMediumIdEdit", GWEN_DialogProperty_Value, 0, NULL);
