@@ -113,8 +113,8 @@ typedef int (*AH_JOB_NEXTMSG_FN)(AH_JOB *j);
 /*@{*/
 AH_JOB *AH_Job_new(const char *name,
                    AB_USER *u,
-		   const char *accountId,
-		   int jobVersion);
+                   AB_ACCOUNT *acc,
+                   int jobVersion);
 void AH_Job_free(AH_JOB *j);
 void AH_Job_Attach(AH_JOB *j);
 /*@}*/
@@ -125,10 +125,10 @@ void AH_Job_Attach(AH_JOB *j);
  */
 /*@{*/
 const char *AH_Job_GetName(const AH_JOB *j);
-const char *AH_Job_GetAccountId(const AH_JOB *j);
 const char *AH_Job_GetDescription(const AH_JOB *j);
 
 const char *AH_Job_GetCode(const AH_JOB *j);
+const char *AH_Job_GetResponseName(const AH_JOB *j);
 
 int AH_Job_GetMinSignatures(const AH_JOB *j);
 int AH_Job_GetSecurityProfile(const AH_JOB *j);
@@ -310,6 +310,32 @@ int AH_Job_GetMaxVersionUpUntil(const char *name, AB_USER *u, int maxVersion);
 
 int AH_Job_GetSegmentVersion(const AH_JOB *j);
 
+
+int AH_Job_GetTransferCount(AH_JOB *j);
+void AH_Job_IncTransferCount(AH_JOB *j);
+int AH_Job_GetMaxTransfers(AH_JOB *j);
+void AH_Job_SetMaxTransfers(AH_JOB *j, int i);
+
+AB_TRANSACTION_LIST *AH_Job_GetTransferList(const AH_JOB *j);
+void AH_Job_AddTransfer(AH_JOB *j, AB_TRANSACTION *t);
+AB_TRANSACTION *AH_Job_GetFirstTransfer(const AH_JOB *j);
+
+
+/**
+ * Finds a profile of the SEPA ImExporter whose type option matches
+ * the pattern provided in the tmpl parameter. The pattern "001", for
+ * instance, will choose a profile suitable for credit transfer jobs.
+ * Specifying the NULL pointer for tmpl will return the profile
+ * selected during an earlier call to this function for the same job.
+ */
+GWEN_DB_NODE *AH_Job_FindSepaProfile(AH_JOB *j, const char *type,
+                                     const char *name);
+
+
+
+void AH_Job_ReadAccountDataSeg(AB_ACCOUNT *acc, GWEN_DB_NODE *dbAccountData);
+
+
 #endif /* AH_JOB_L_H */
 
 
