@@ -23,8 +23,8 @@ struct AH_JOB {
 
   char *name;
   char *code;
-  char *accountId;
   char *description;
+  char *responseName;
 
   int segmentVersion;
 
@@ -43,12 +43,14 @@ struct AH_JOB {
   uint32_t lastSegment;
 
   GWEN_STRINGLIST *signers;
+  GWEN_STRINGLIST *sepaDescriptors;
 
   GWEN_XMLNODE *xmlNode;
   GWEN_XMLNODE *msgNode;
   GWEN_DB_NODE *jobParams;
   GWEN_DB_NODE *jobArguments;
   GWEN_DB_NODE *jobResponses;
+  GWEN_DB_NODE *sepaProfile;
 
   AH_JOB_STATUS status;
   uint32_t flags;
@@ -82,6 +84,10 @@ struct AH_JOB {
 
   GWEN_STRINGLIST *challengeParams;
   AB_VALUE *challengeValue;
+
+  int maxTransfers;
+  int transferCount;
+  AB_TRANSACTION_LIST *transferList;
 };
 
 
