@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: jobqueue_l.h 1041 2006-07-03 17:14:56Z martin $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -54,6 +54,8 @@ AH_JOBQUEUE *AH_JobQueue_new(AB_USER *u);
 void AH_JobQueue_free(AH_JOBQUEUE *jq);
 void AH_JobQueue_Attach(AH_JOBQUEUE *jq);
 
+AH_JOBQUEUE *AH_JobQueue_fromQueue(AH_JOBQUEUE *oldq);
+
 AB_USER *AH_JobQueue_GetUser(const AH_JOBQUEUE *jq);
 
 AH_JOBQUEUE_ADDRESULT AH_JobQueue_AddJob(AH_JOBQUEUE *jq,
@@ -62,7 +64,7 @@ AH_JOBQUEUE_ADDRESULT AH_JobQueue_AddJob(AH_JOBQUEUE *jq,
 const AH_JOB_LIST *AH_JobQueue_GetJobList(const AH_JOBQUEUE *jq);
 AH_JOB_LIST *AH_JobQueue_TakeJobList(AH_JOBQUEUE *jq);
 
-GWEN_TYPE_UINT32 AH_JobQueue_GetMsgNum(const AH_JOBQUEUE *jq);
+uint32_t AH_JobQueue_GetMsgNum(const AH_JOBQUEUE *jq);
 
 AH_MSG *AH_JobQueue_ToMessage(AH_JOBQUEUE *jq, AH_DIALOG *dlg);
 
@@ -78,10 +80,10 @@ void AH_JobQueue_Dump(AH_JOBQUEUE *jq, FILE *f, unsigned int insert);
 
 void AH_JobQueue_AddSigner(AH_JOBQUEUE *jq, const char *s);
 
-GWEN_TYPE_UINT32 AH_JobQueue_GetFlags(AH_JOBQUEUE *jq);
-void AH_JobQueue_SetFlags(AH_JOBQUEUE *jq, GWEN_TYPE_UINT32 f);
-void AH_JobQueue_AddFlags(AH_JOBQUEUE *jq, GWEN_TYPE_UINT32 f);
-void AH_JobQueue_SubFlags(AH_JOBQUEUE *jq, GWEN_TYPE_UINT32 f);
+uint32_t AH_JobQueue_GetFlags(AH_JOBQUEUE *jq);
+void AH_JobQueue_SetFlags(AH_JOBQUEUE *jq, uint32_t f);
+void AH_JobQueue_AddFlags(AH_JOBQUEUE *jq, uint32_t f);
+void AH_JobQueue_SubFlags(AH_JOBQUEUE *jq, uint32_t f);
 
 void AH_JobQueue_SetJobStatusOnMatch(AH_JOBQUEUE *jq,
                                      AH_JOB_STATUS matchSt,
