@@ -773,6 +773,10 @@ int AH_Msg_DecryptRdh2(AH_MSG *hmsg, GWEN_DB_NODE *gr){
     int ksize;
 
     ksize=GWEN_Crypt_Token_KeyInfo_GetKeySize(ki);
+    if (ksize<l) {
+      DBG_WARN(AQHBCI_LOGDOMAIN, "Keyinfo keysize is smaller than size of transmitted key, adjusting");
+      ksize=l;
+    }
     assert(ksize<=256);
 
     /* fill encoded key with 0 */
