@@ -13,6 +13,7 @@
 #include "user_l.h"
 
 #include <gwenhywfar/buffer.h>
+#include <gwenhywfar/cryptkeyrsa.h>
 
 #define AH_USER_MAX_TANMETHODS 16
 
@@ -61,9 +62,14 @@ struct AH_USER {
 
   AH_TAN_METHOD_LIST *tanMethodDescriptions;
   char *tanMediumId;
+  GWEN_STRINGLIST *sepaDescriptors;
+  char *sepaTransferProfile;
+  char *sepaDebitNoteProfile;
 
   int maxTransfersPerJob;
   int maxDebitNotesPerJob;
+
+  GWEN_CRYPT_KEY * bankPubKey;
 };
 
 static void GWENHYWFAR_CB AH_User_freeData(void *bp, void *p);
@@ -72,11 +78,17 @@ static void AH_User_ReadDb(AB_USER *u, GWEN_DB_NODE *db);
 static void AH_User_toDb(AB_USER *u, GWEN_DB_NODE *db);
 
 static void AH_User_LoadTanMethods(AB_USER *u);
+static void AH_User_LoadSepaDescriptors(AB_USER *u);
 
 
 static int AH_User_AddTextWithoutTags(const char *s, GWEN_BUFFER *obuf);
 
 
+static GWEN_DB_NODE *AH_User_GetUpdForAccountIdAndSuffix(const AB_USER *u,
+                                                         const char *sAccountNumber,
+                                                         const char *sAccountSuffix);
+
+
 #endif /* AH_USER_P_H */
 
 
