@@ -27,8 +27,11 @@ struct AO_USER {
   char *headerVer;
   char *clientUid;
 
+  char *securityType;
+
   int httpVMajor;
   int httpVMinor;
+  char *httpUserAgent;
 };
 
 static void GWENHYWFAR_CB AO_User_FreeData(void *bp, void *p);
