@@ -676,7 +676,7 @@ int APY_NewUserDialog_DoIt(GWEN_DIALOG *dlg) {
   uint32_t pid;
   AB_PROVIDER *pro;
 
-  DBG_ERROR(0, "Doit");
+  DBG_INFO(0, "Doit");
   assert(dlg);
   xdlg=GWEN_INHERIT_GETDATA(GWEN_DIALOG, APY_NEWUSER_DIALOG, dlg);
   assert(xdlg);
@@ -688,7 +688,7 @@ int APY_NewUserDialog_DoIt(GWEN_DIALOG *dlg) {
     return GWEN_DialogEvent_ResultHandled;
   }
 
-  DBG_ERROR(0, "Creating user");
+  DBG_INFO(0, "Creating user");
   u=AB_Banking_CreateUser(xdlg->banking, "aqpaypal");
   if (u==NULL) {
     DBG_ERROR(AQPAYPAL_LOGDOMAIN, "Could not create user, maybe backend missing?");
@@ -707,7 +707,7 @@ int APY_NewUserDialog_DoIt(GWEN_DIALOG *dlg) {
   APY_User_SetHttpVMajor(u, xdlg->httpVMajor);
   APY_User_SetHttpVMinor(u, xdlg->httpVMinor);
 
-  DBG_ERROR(0, "Adding user");
+  DBG_INFO(0, "Adding user");
   rv=AB_Banking_AddUser(xdlg->banking, u);
   if (rv<0) {
     DBG_ERROR(AQPAYPAL_LOGDOMAIN, "Could not add user (%d)", rv);
@@ -724,7 +724,7 @@ int APY_NewUserDialog_DoIt(GWEN_DIALOG *dlg) {
 			     3,
 			     0);
   /* lock new user */
-  DBG_ERROR(0, "Locking user");
+  DBG_INFO(0, "Locking user");
   rv=AB_Banking_BeginExclUseUser(xdlg->banking, u);
   if (rv<0) {
     DBG_ERROR(AQPAYPAL_LOGDOMAIN, "Could not lock user (%d)", rv);
@@ -737,7 +737,7 @@ int APY_NewUserDialog_DoIt(GWEN_DIALOG *dlg) {
   }
 
 #if 0
-  DBG_ERROR(0, "Getting certs (%08x)", AH_User_GetFlags(u));
+  DBG_INFO(0, "Getting certs (%08x)", AH_User_GetFlags(u));
   GWEN_Gui_ProgressLog(pid,
 		       GWEN_LoggerLevel_Notice,
 		       I18N("Retrieving SSL certificate"));
@@ -781,7 +781,7 @@ int APY_NewUserDialog_DoIt(GWEN_DIALOG *dlg) {
 
 
   /* unlock user */
-  DBG_ERROR(0, "Unlocking user");
+  DBG_INFO(0, "Unlocking user");
   rv=AB_Banking_EndExclUseUser(xdlg->banking, u, 0);
   if (rv<0) {
     DBG_INFO(AQPAYPAL_LOGDOMAIN,
@@ -800,6 +800,7 @@ int APY_NewUserDialog_DoIt(GWEN_DIALOG *dlg) {
   if (1) {
     AB_ACCOUNT *account;
     int rv;
+    static char accountname[256];
 
     account=AB_Banking_CreateAccount(xdlg->banking, APY_PROVIDER_NAME);
     assert(account);
@@ -810,6 +811,10 @@ int APY_NewUserDialog_DoIt(GWEN_DIALOG *dlg) {
     AB_Account_SetOwnerName(account, AB_User_GetUserName(u));
     AB_Account_SetAccountNumber(account, AB_User_GetUserId(u));
     AB_Account_SetBankCode(account, "PAYPAL");
+    AB_Account_SetBankName(account, "PAYPAL");
+    strcpy(accountname, "PP ");
+    strcat(accountname, AB_User_GetUserName(u));
+    AB_Account_SetAccountName(account, accountname);
     AB_Account_SetUser(account, u);
     AB_Account_SetSelectedUser(account, u);
 
@@ -923,7 +928,7 @@ int APY_NewUserDialog_HandleActivatedSpecial(GWEN_DIALOG *dlg) {
 
 
 int APY_NewUserDialog_HandleActivated(GWEN_DIALOG *dlg, const char *sender) {
-  DBG_ERROR(0, "Activated: %s", sender);
+  DBG_INFO(0, "Activated: %s", sender);
   if (strcasecmp(sender, "wiz_prev_button")==0)
     return APY_NewUserDialog_Previous(dlg);
   else if (strcasecmp(sender, "wiz_next_button")==0)
