@@ -1,6 +1,6 @@
 /***************************************************************************
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004-2010 by Martin Preuss
+    copyright   : (C) 2004,2012 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -74,6 +74,7 @@ void GWENHYWFAR_CB AH_ImExporterCSV_FreeData(void *bp, void *p){
   AH_IMEXPORTER_CSV *ieh;
 
   ieh=(AH_IMEXPORTER_CSV*)p;
+  GWEN_DBIO_free(ieh->dbio);
   GWEN_FREE_OBJECT(ieh);
 }
 
@@ -329,6 +330,18 @@ int AH_ImExporterCSV__ImportFromGroup(AB_IMEXPORTER_CONTEXT *ctx,
           GWEN_Time_free(ti);
         }
 
+        /* translate mandateDate */
+        p=GWEN_DB_GetCharValue(dbT, "mandateDate", 0, 0);
+        if (p) {
+	  GWEN_DATE *dt;
+
+	  dt=GWEN_Date_fromStringWithTemplate(p, dateFormat);
+	  if (dt) {
+	    AB_Transaction_SetMandateDate(t, dt);
+	    GWEN_Date_free(dt);
+	  }
+	}
+
         /* possibly translate value */
 	if (usePosNegField) {
           const char *s;
@@ -442,7 +455,7 @@ int AH_ImExporterCSV__ImportFromGroup(AB_IMEXPORTER_CONTEXT *ctx,
         AB_ImExporterContext_AddTransaction(ctx, t);
       }
       else {
-        DBG_ERROR(AQBANKING_LOGDOMAIN, "Empty group");
+        DBG_ERROR(AQBANKING_LOGDOMAIN, "Empty group (i.e. empty line in imported file)");
       }
     }
     else {
@@ -500,7 +513,7 @@ int AH_ImExporterCSV__ExportTransactions(AB_IMEXPORTER *ie,
 					 AB_IMEXPORTER_CONTEXT *ctx,
 					 GWEN_SYNCIO *sio,
 					 GWEN_DB_NODE *params,
-					 int noted){
+					 int notedOrTransfers){
   AH_IMEXPORTER_CSV *ieh;
   AB_IMEXPORTER_ACCOUNTINFO *ai;
   GWEN_DB_NODE *dbData;
@@ -538,13 +551,29 @@ int AH_ImExporterCSV__ExportTransactions(AB_IMEXPORTER *ie,
   while(ai) {
     const AB_TRANSACTION *t;
 
-    if (noted)
-      t=AB_ImExporterAccountInfo_GetFirstNotedTransaction(ai);
-    else
+    switch(notedOrTransfers) {
+    case AH_IMEXPORTERCSV_SUBJECT_TRANSACTIONS:
       t=AB_ImExporterAccountInfo_GetFirstTransaction(ai);
+      break;
+    case AH_IMEXPORTERCSV_SUBJECT_NOTEDTRANSACTIONS:
+      t=AB_ImExporterAccountInfo_GetFirstNotedTransaction(ai);
+      break;
+    case AH_IMEXPORTERCSV_SUBJECT_TRANSFERS:
+      t=AB_ImExporterAccountInfo_GetFirstTransfer(ai);
+      break;
+    default:
+      DBG_ERROR(AQBANKING_LOGDOMAIN,
+		"Invalid subject type %d", notedOrTransfers);
+      GWEN_Gui_ProgressLog2(0, GWEN_LoggerLevel_Error,
+			    "Invalid subject type %d", notedOrTransfers);
+      GWEN_DB_Group_free(dbData);
+      return GWEN_ERROR_GENERIC;
+    }
+
     while(t) {
       GWEN_DB_NODE *dbTransaction;
       const GWEN_TIME *ti;
+      const GWEN_DATE *dt;
 
       dbTransaction=GWEN_DB_Group_new("transaction");
       rv=AB_Transaction_toDb(t, dbTransaction);
@@ -561,6 +590,7 @@ int AH_ImExporterCSV__ExportTransactions(AB_IMEXPORTER *ie,
       /* transform dates */
       GWEN_DB_DeleteGroup(dbTransaction, "date");
       GWEN_DB_DeleteGroup(dbTransaction, "valutaDate");
+      GWEN_DB_DeleteGroup(dbTransaction, "mandateDate");
 
       ti=AB_Transaction_GetDate(t);
       if (ti) {
@@ -599,6 +629,22 @@ int AH_ImExporterCSV__ExportTransactions(AB_IMEXPORTER *ie,
 	GWEN_Buffer_free(tbuf);
       }
 
+      dt=AB_Transaction_GetMandateDate(t);
+      if (dt) {
+	GWEN_BUFFER *tbuf;
+        int rv;
+
+	tbuf=GWEN_Buffer_new(0, 32, 0, 1);
+	rv=GWEN_Date_toStringWithTemplate(dt, dateFormat, tbuf);
+	if (rv<0) {
+	  DBG_WARN(AQBANKING_LOGDOMAIN, "Bad date format string/date");
+	}
+	else
+	  GWEN_DB_SetCharValue(dbTransaction, GWEN_DB_FLAGS_OVERWRITE_VARS,
+			       "mandateDate", GWEN_Buffer_GetStart(tbuf));
+	GWEN_Buffer_free(tbuf);
+      }
+
       /* possibly transform value */
       if (usePosNegField) {
 	const AB_VALUE *v;
@@ -698,10 +744,25 @@ int AH_ImExporterCSV__ExportTransactions(AB_IMEXPORTER *ie,
 
       /* add transaction db */
       GWEN_DB_AddGroup(dbData, dbTransaction);
-      if (noted)
-	t=AB_ImExporterAccountInfo_GetNextNotedTransaction(ai);
-      else
+
+      switch(notedOrTransfers) {
+      case AH_IMEXPORTERCSV_SUBJECT_TRANSACTIONS:
 	t=AB_ImExporterAccountInfo_GetNextTransaction(ai);
+	break;
+      case AH_IMEXPORTERCSV_SUBJECT_NOTEDTRANSACTIONS:
+	t=AB_ImExporterAccountInfo_GetNextNotedTransaction(ai);
+	break;
+      case AH_IMEXPORTERCSV_SUBJECT_TRANSFERS:
+	t=AB_ImExporterAccountInfo_GetNextTransfer(ai);
+	break;
+      default:
+	DBG_ERROR(AQBANKING_LOGDOMAIN,
+		  "Invalid subject type %d", notedOrTransfers);
+	GWEN_Gui_ProgressLog2(0, GWEN_LoggerLevel_Error,
+			      "Invalid subject type %d", notedOrTransfers);
+	GWEN_DB_Group_free(dbData);
+	return GWEN_ERROR_GENERIC;
+      }
     }
     ai=AB_ImExporterContext_GetNextAccountInfo(ctx);
   }
@@ -740,9 +801,11 @@ int AH_ImExporterCSV_Export(AB_IMEXPORTER *ie,
   subject=GWEN_DB_GetCharValue(params, "subject", 0,
 			       "transactions");
   if (strcasecmp(subject, "transactions")==0)
-    return AH_ImExporterCSV__ExportTransactions(ie, ctx, sio, params, 0);
+    return AH_ImExporterCSV__ExportTransactions(ie, ctx, sio, params, AH_IMEXPORTERCSV_SUBJECT_TRANSACTIONS);
   else if (strcasecmp(subject, "notedTransactions")==0)
-    return AH_ImExporterCSV__ExportTransactions(ie, ctx, sio, params, 1);
+    return AH_ImExporterCSV__ExportTransactions(ie, ctx, sio, params, AH_IMEXPORTERCSV_SUBJECT_NOTEDTRANSACTIONS);
+  else if (strcasecmp(subject, "transfers")==0)
+    return AH_ImExporterCSV__ExportTransactions(ie, ctx, sio, params, AH_IMEXPORTERCSV_SUBJECT_TRANSFERS);
   else {
     DBG_ERROR(AQBANKING_LOGDOMAIN,
 	      "Unable to export unknown subject \"%s\"", subject);
