@@ -25,9 +25,7 @@ GWEN_DBIO *AHB_DTAUS_Factory(GWEN_PLUGIN *pl);
 GWEN_DBIO_CHECKFILE_RESULT AHB_DTAUS__ReallyCheckFile(GWEN_BUFFER *src,
                                                       unsigned int pos);
 GWEN_DBIO_CHECKFILE_RESULT AHB_DTAUS__CheckFile(GWEN_DBIO *dbio,
-						const char *fname,
-						uint32_t guiid,
-						int msecs);
+						const char *fname);
 
 
 
