@@ -14,6 +14,7 @@
 
 #include "swift_p.h"
 #include "swift940_l.h"
+#include "swift535_l.h"
 #include "i18n_l.h"
 #include <aqbanking/banking.h>
 #include <gwenhywfar/text.h>
@@ -85,7 +86,17 @@ int AHB_SWIFT_Condense(char *buffer, int keepMultipleBlanks) {
 
 
 
+/* Create a tag object from a tag ID and the content of the tag. Example:
+   Given the following line inside a SWIFT data block:
 
+     :28C:7/1
+
+   You'd call AHB_SWIFT_Tag_new like this:
+
+     AHB_SWIFT_Tag_new("28C", "7/1")
+
+   @return a new AHB_SWIFT_TAG
+ */
 AHB_SWIFT_TAG *AHB_SWIFT_Tag_new(const char *id,
                                  const char *content){
   AHB_SWIFT_TAG *tg;
@@ -298,7 +309,11 @@ int AHB_SWIFT_ParseSubTags(const char *s, AHB_SWIFT_SUBTAG_LIST *stlist, int kee
 
 
 
-
+/* This reads a line within a SWIFT data block (block 4)
+   @param *fb     pointer to a GWEN_FAST_BUFFER input buffer
+   @param *buffer pointer to a char* output buffer 
+   @param s       size of the output buffer
+   */
 int AHB_SWIFT_ReadLine(GWEN_FAST_BUFFER *fb,
                        char *buffer,
 		       unsigned int s){
@@ -368,8 +383,10 @@ int AHB_SWIFT_ReadLine(GWEN_FAST_BUFFER *fb,
 
 
 
-
-int AHB_SWIFT__ReadDocument(GWEN_FAST_BUFFER *fb,
+/* This will read the contents of a SWIFT data block ({4: ... })
+   inside of a SWIFT document
+ */
+int AHB_SWIFT_ReadTextBlock(GWEN_FAST_BUFFER *fb,
 			    AHB_SWIFT_TAG_LIST *tl,
                             unsigned int maxTags) {
   GWEN_BUFFER *lbuf;
@@ -463,15 +480,20 @@ int AHB_SWIFT__ReadDocument(GWEN_FAST_BUFFER *fb,
       if (buffer[0]==':') {
 	const char *s;
 
-	s=buffer+1;
-	while(*s && isdigit(*s))
-	  s++;
-	if (isalpha(*s))
-	  s++;
-	if (*s==':') {
-	  DBG_DEBUG(AQBANKING_LOGDOMAIN, "End of tag reached");
+	if (strncasecmp(buffer, ":NS:", 4)==0) {
 	  break;
 	}
+        else {
+	  s=buffer+1;
+	  while(*s && isdigit(*s))
+	    s++;
+	  if (isalpha(*s))
+	    s++;
+	  if (*s==':') {
+	    DBG_DEBUG(AQBANKING_LOGDOMAIN, "End of tag reached");
+	    break;
+	  }
+	}
       }
 
       /* check whether the line starts with a ":" or "-" */
@@ -539,7 +561,7 @@ int AHB_SWIFT__ReadDocument(GWEN_FAST_BUFFER *fb,
 }
 
 
-
+#if 0
 int AHB_SWIFT_ReadDocument(GWEN_FAST_BUFFER *fb,
 			   AHB_SWIFT_TAG_LIST *tl,
 			   unsigned int maxTags) {
@@ -621,7 +643,7 @@ int AHB_SWIFT_ReadDocument(GWEN_FAST_BUFFER *fb,
     } /* for */
   }
 
-  rv=AHB_SWIFT__ReadDocument(fb, tl, maxTags);
+  rv=AHB_SWIFT_ReadTextBlock(fb, tl, maxTags);
   if (rv)
     return rv;
 
@@ -665,9 +687,14 @@ int AHB_SWIFT_ReadDocument(GWEN_FAST_BUFFER *fb,
 	bsize=3;
 	GWEN_FASTBUFFER_READFORCED(fb, err, swhead, bsize);
 	if (err<0) {
+	  if (err==GWEN_ERROR_EOF) {
+	    DBG_ERROR(AQBANKING_LOGDOMAIN,
+		      "EOF met (%d)", c);
+	    return 0;
+	  }
 	  DBG_ERROR_ERR(AQBANKING_LOGDOMAIN, err);
 	  return err;
-        }
+	}
 #if 0
 	if (swhead[2]!=':') {
           DBG_ERROR(AQBANKING_LOGDOMAIN, "Not a SWIFT block");
@@ -681,8 +708,8 @@ int AHB_SWIFT_ReadDocument(GWEN_FAST_BUFFER *fb,
             if (c==GWEN_ERROR_EOF) {
               DBG_ERROR(AQBANKING_LOGDOMAIN,
                         "EOF met (%d)", c);
-	      return GWEN_ERROR_EOF;
-            }
+	      return 0;
+	    }
             DBG_ERROR(AQBANKING_LOGDOMAIN,
                       "Error reading from BIO (%d)", c);
 	    return GWEN_ERROR_READ;
@@ -705,6 +732,131 @@ int AHB_SWIFT_ReadDocument(GWEN_FAST_BUFFER *fb,
 
   return 0;
 }
+#endif
+
+
+
+int AHB_SWIFT_ReadDocument(GWEN_FAST_BUFFER *fb,
+			   AHB_SWIFT_TAG_LIST *tl,
+			   unsigned int maxTags) {
+  int rv;
+  int c;
+  int isFullSwift=0;
+  int subDocs=0;
+
+  /* check for first character being a curly bracket */
+  for (;;) {
+    GWEN_FASTBUFFER_PEEKBYTE(fb, c);
+    if (c<0) {
+      if (c==GWEN_ERROR_EOF) {
+	DBG_INFO(AQBANKING_LOGDOMAIN,
+		 "EOF met, empty document");
+	return 1;
+      }
+      DBG_ERROR(AQBANKING_LOGDOMAIN,
+		"Error reading from BIO (%d)", c);
+      return c;
+    }
+    if (c=='{') {
+      isFullSwift=1;
+      break;
+    }
+    else if (c>3)
+      /* some SWIFT documents contain 01 at the beginning and 03 at the end,
+       * we simply skip those characters here */
+      break;
+    GWEN_FASTBUFFER_READBYTE(fb, c);
+  } /* for */
+
+  if (isFullSwift) {
+    /* read header, seek block 4 */
+    for (;;) {
+      int err;
+      char swhead[4];
+      unsigned int bsize;
+      int curls=0;
+
+      /* skip everything before curly bracket */
+      for (;;) {
+	GWEN_FASTBUFFER_PEEKBYTE(fb, c);
+	if (c<0) {
+	  if (c==GWEN_ERROR_EOF) {
+	    DBG_INFO(AQBANKING_LOGDOMAIN, "EOF met, empty block");
+	    if (subDocs>0) {
+	      DBG_INFO(AQBANKING_LOGDOMAIN, "We got %d text blocks, returning", subDocs);
+	      return 0;
+	    }
+	    return 1;
+	  }
+	  DBG_ERROR(AQBANKING_LOGDOMAIN,
+		    "Error reading from BIO (%d)", c);
+	  return c;
+	}
+	if (c=='{') {
+	  break;
+	}
+	GWEN_FASTBUFFER_READBYTE(fb, c);
+      } /* for */
+
+      /* read block start ("{n:...") */
+      bsize=3;
+
+      GWEN_FASTBUFFER_READFORCED(fb, err, swhead, bsize);
+      if (err<0) {
+        DBG_ERROR_ERR(AQBANKING_LOGDOMAIN, err);
+	return err;
+      }
+      if (swhead[2]!=':') {
+        DBG_ERROR(AQBANKING_LOGDOMAIN, "Not a SWIFT block");
+	GWEN_Text_DumpString(swhead, 4, 2);
+	return GWEN_ERROR_BAD_DATA;
+      }
+
+      /* handle block */
+      DBG_DEBUG(0, "Reading block %d", swhead[1]-'0');
+      if (swhead[1]=='4') {
+	/* read document from block 4 */
+	rv=AHB_SWIFT_ReadTextBlock(fb, tl, maxTags);
+	if (rv) {
+	  DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+	  return rv;
+	}
+	subDocs++;
+      }
+
+      /* skip block */
+      for (;;) {
+	GWEN_FASTBUFFER_READBYTE(fb, c);
+	if (c<0) {
+	  if (c==GWEN_ERROR_EOF) {
+	    DBG_ERROR(AQBANKING_LOGDOMAIN,
+		      "EOF met (%d)", c);
+	    return GWEN_ERROR_EOF;
+	  }
+	  DBG_ERROR(AQBANKING_LOGDOMAIN,
+		    "Error reading from BIO (%d)", c);
+	  return GWEN_ERROR_READ;
+	}
+	if (c=='{')
+	  curls++;
+	else if (c=='}') {
+	  if (curls==0)
+	    break;
+	  else
+	    curls--;
+	}
+      } /* for */
+    } /* for */
+  }
+  else {
+    /* not a full swift document, just read the SWIFT document directly */
+    rv=AHB_SWIFT_ReadTextBlock(fb, tl, maxTags);
+    if (rv)
+      return rv;
+  }
+
+  return 0;
+}
 
 
 
@@ -722,7 +874,8 @@ int AHB_SWIFT_Import(GWEN_DBIO *dbio,
 
   p=GWEN_DB_GetCharValue(cfg, "type", 0, "mt940");
   if (strcasecmp(p, "mt940")!=0 &&
-      strcasecmp(p, "mt942")!=0) {
+      strcasecmp(p, "mt942")!=0 &&
+      strcasecmp(p, "mt535")!=0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN,
               "Type \"%s\" not supported by plugin \"%s\"",
               p,
@@ -772,19 +925,16 @@ int AHB_SWIFT_Import(GWEN_DBIO *dbio,
   for (;;) {
     AHB_SWIFT_TAG_LIST *tl;
 
-    tl=AHB_SWIFT_Tag_List_new();
-
     /* check for user abort */
     rv=GWEN_Gui_ProgressAdvance(0, GWEN_GUI_PROGRESS_NONE);
     if (rv==GWEN_ERROR_USER_ABORTED) {
       DBG_INFO(AQBANKING_LOGDOMAIN, "User aborted");
       GWEN_FastBuffer_free(fb);
-      AHB_SWIFT_Tag_List_free(tl);
       return rv;
     }
 
-    GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Debug,
-			 I18N("Reading SWIFT document"));
+    GWEN_Gui_ProgressLog2(0, GWEN_LoggerLevel_Debug,
+                          I18N("Reading SWIFT document %d"), docsImported+1);
 
     /* skip lines at the beginning if requested */
     if (skipDocLines>0) {
@@ -803,7 +953,6 @@ int AHB_SWIFT_Import(GWEN_DBIO *dbio,
 		   "Error in report, aborting (%d)", err);
 	  GWEN_Buffer_free(lbuf);
 	  GWEN_FastBuffer_free(fb);
-	  AHB_SWIFT_Tag_List_free(tl);
 	  return err;
 	}
 	GWEN_Buffer_Reset(lbuf);
@@ -817,6 +966,8 @@ int AHB_SWIFT_Import(GWEN_DBIO *dbio,
 
     GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Debug,
 			 I18N("Parsing SWIFT data"));
+    tl=AHB_SWIFT_Tag_List_new();
+    assert(tl);
     rv=AHB_SWIFT_ReadDocument(fb, tl, 0);
     if (rv<0) {
       DBG_INFO(AQBANKING_LOGDOMAIN, "Error in report, aborting");
@@ -829,12 +980,12 @@ int AHB_SWIFT_Import(GWEN_DBIO *dbio,
 
     if (rv==1) {
       DBG_INFO(AQBANKING_LOGDOMAIN, "End of document reached");
+      AHB_SWIFT_Tag_List_free(tl);
       if (docsImported==0) {
 	DBG_INFO(AQBANKING_LOGDOMAIN, "Empty document, aborting");
 	GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Error,
 			     I18N("Empty SWIFT document, aborting"));
 	GWEN_FastBuffer_free(fb);
-	AHB_SWIFT_Tag_List_free(tl);
         return GWEN_ERROR_EOF;
       }
       break;
@@ -843,22 +994,30 @@ int AHB_SWIFT_Import(GWEN_DBIO *dbio,
     /* now all tags have been read, transform them */
     GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Debug,
 			 I18N("Importing SWIFT data"));
-    rv=AHB_SWIFT940_Import(tl, data, cfg, flags);
+
+    DBG_INFO(AQBANKING_LOGDOMAIN, "*** before branching ***");
+    if(strcasecmp(p, "mt940")==0 || strcasecmp(p, "mt942")==0)
+      rv=AHB_SWIFT940_Import(tl, data, cfg, flags);
+    if(strcasecmp(p, "mt535")==0)
+      rv=AHB_SWIFT535_Import(tl, data, cfg, flags);
+
+    
     if (rv) {
-      DBG_INFO(AQBANKING_LOGDOMAIN, "Error importing SWIFT MT940");
+      DBG_INFO(AQBANKING_LOGDOMAIN, "Error importing SWIFT MT940/942/535");
       GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Error,
 			   I18N("Error importing SWIFT data"));
       GWEN_FastBuffer_free(fb);
       AHB_SWIFT_Tag_List_free(tl);
       return rv;
     }
+    AHB_SWIFT_Tag_List_free(tl);
     GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Debug,
 			 I18N("Swift document successfully imported"));
     docsImported++;
   } /* for */
 
   GWEN_FastBuffer_free(fb);
-  DBG_INFO(AQBANKING_LOGDOMAIN, "SWIFT MT940 successfully imported");
+  DBG_INFO(AQBANKING_LOGDOMAIN, "SWIFT MT940/942/535 successfully imported");
 
   return 0;
 }
@@ -898,6 +1057,7 @@ GWEN_DBIO_CHECKFILE_RESULT AHB_SWIFT_CheckFile(GWEN_DBIO *dbio,
     /* error */
     DBG_ERROR(AQBANKING_LOGDOMAIN,
 	      "open(%s): %s", fname, strerror(errno));
+    GWEN_SyncIo_free(sio);
     return GWEN_DBIO_CheckFileResultNotOk;
   }
 
