@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Fri Apr 02 2004
- copyright   : (C) 2004 by Martin Preuss
+ copyright   : (C) 2004-2010 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -20,9 +17,7 @@
 int AHB_SWIFT940_Import(AHB_SWIFT_TAG_LIST *tl,
 			GWEN_DB_NODE *data,
 			GWEN_DB_NODE *cfg,
-			uint32_t flags,
-			uint32_t guiid,
-			int msecs);
+			uint32_t flags);
 
 
 #endif /* AQHBCIBANK_SWIFT940_P_H */
