@@ -51,61 +51,6 @@ int test1(int argc, char **argv) {
 }
 
 
-int test2(int argc, char **argv) {
-  AB_BANKING *ab;
-  int rv;
-  GWEN_PLUGIN_DESCRIPTION_LIST2 *pdl;
-  GWEN_PLUGIN_DESCRIPTION_LIST2_ITERATOR *pit;
-  GWEN_PLUGIN_DESCRIPTION *pd;
-
-  fprintf(stderr, "Creating AB_Banking...\n");
-  ab=AB_Banking_new("abtest", "./aqbanking.conf", 0);
-
-  fprintf(stderr, "Initializing AB_Banking...\n");
-  rv=AB_Banking_Init(ab);
-  if (rv) {
-    fprintf(stderr, "Could not init AqBanking (%d)\n", rv);
-    return 2;
-  }
-
-  pdl=AB_Banking_GetProviderDescrs(ab);
-  if (!pdl) {
-    fprintf(stderr, "No providers...\n");
-    return 2;
-  }
-
-  pit=GWEN_PluginDescription_List2_First(pdl);
-  assert(pit);
-  pd=GWEN_PluginDescription_List2Iterator_Data(pit);
-  assert(pd);
-  while(pd) {
-    fprintf(stderr, "Backend:\n");
-    fprintf(stderr, "Name        : %s (%s)\n",
-            GWEN_PluginDescription_GetName(pd),
-            GWEN_PluginDescription_GetVersion(pd));
-    fprintf(stderr, "Author      : %s\n",
-            GWEN_PluginDescription_GetAuthor(pd));
-    fprintf(stderr, "Short Descr.: %s\n",
-            GWEN_PluginDescription_GetShortDescr(pd));
-    pd=GWEN_PluginDescription_List2Iterator_Next(pit);
-  } /* while */
-
-  fprintf(stderr, "Deinitializing AB_Banking...\n");
-  rv=AB_Banking_Fini(ab);
-  if (rv) {
-    fprintf(stderr, "Could not deinit AqBanking (%d)\n", rv);
-    return 2;
-  }
-
-  fprintf(stderr, "Freeing AB_Banking...\n");
-  AB_Banking_free(ab);
-
-  fprintf(stderr, "Finished\n");
-  return 0;
-}
-
-
-
 int test3(int argc, char **argv) {
   AB_BANKING *ab;
   int rv;
@@ -138,55 +83,6 @@ int test3(int argc, char **argv) {
 
 
 
-int test4(int argc, char **argv) {
-  AB_BANKING *ab;
-  int rv;
-  GWEN_BUFFER *pbuf;
-
-  fprintf(stderr, "Creating AB_Banking...\n");
-  ab=AB_Banking_new("abtest", "./aqbanking.conf", 0);
-
-  fprintf(stderr, "Initializing AB_Banking...\n");
-  rv=AB_Banking_Init(ab);
-  if (rv) {
-    fprintf(stderr, "Could not init AqBanking (%d)\n", rv);
-    return 2;
-  }
-
-  pbuf=GWEN_Buffer_new(0, 256, 0, 1);
-  if (AB_Banking_FindDebugger(ab, "aqhbci", "kde;qt;gnome;gtk", pbuf)) {
-    fprintf(stderr, "Debugger not found.\n");
-    return 2;
-  }
-  fprintf(stderr, "Debugger found: %s\n",
-          GWEN_Buffer_GetStart(pbuf));
-  GWEN_Buffer_free(pbuf);
-
-  pbuf=GWEN_Buffer_new(0, 256, 0, 1);
-  if (AB_Banking_FindWizard(ab, "aqhbci", "kde;qt;gnome;gtk", pbuf)) {
-    fprintf(stderr, "Wizard not found.\n");
-    return 2;
-  }
-  fprintf(stderr, "Wizard found: %s\n",
-          GWEN_Buffer_GetStart(pbuf));
-  GWEN_Buffer_free(pbuf);
-
-  fprintf(stderr, "Deinitializing AB_Banking...\n");
-  rv=AB_Banking_Fini(ab);
-  if (rv) {
-    fprintf(stderr, "Could not deinit AqBanking (%d)\n", rv);
-    return 2;
-  }
-
-  fprintf(stderr, "Freeing AB_Banking...\n");
-  AB_Banking_free(ab);
-
-  fprintf(stderr, "Finished\n");
-  return 0;
-}
-
-
-
 int test5(int argc, char **argv) {
   int rv;
   GWEN_DB_NODE *db;
@@ -197,12 +93,12 @@ int test5(int argc, char **argv) {
   GWEN_DB_SetCharValue(dbParams, GWEN_DB_FLAGS_DEFAULT,
                        "params/type", "mt940");
   rv=GWEN_DB_ReadFileAs(db, "test.swift", "swift", dbParams,
-			GWEN_PATH_FLAGS_CREATE_GROUP, 0, 2000);
+			GWEN_PATH_FLAGS_CREATE_GROUP);
   if (rv) {
     DBG_ERROR(0, "Error reading file");
     return 2;
   }
-  GWEN_DB_Dump(db, stderr, 2);
+  GWEN_DB_Dump(db, 2);
 
   return 0;
 }
@@ -254,12 +150,12 @@ int test6(int argc, char **argv) {
                        "columns/12", "v[11]");
 
   rv=GWEN_DB_ReadFileAs(db, "test.txt", "csv", dbParams,
-			GWEN_PATH_FLAGS_CREATE_GROUP, 0, 2000);
+			GWEN_PATH_FLAGS_CREATE_GROUP);
   if (rv) {
     DBG_ERROR(0, "Error reading file");
     return 2;
   }
-  GWEN_DB_Dump(db, stderr, 2);
+  GWEN_DB_Dump(db, 2);
 
   dbOut=GWEN_DB_Group_new("out");
   GWEN_DB_ClearGroup(dbParams, 0);
@@ -310,7 +206,7 @@ int test6(int argc, char **argv) {
   }
 
   rv=GWEN_DB_WriteFileAs(dbOut, "countries.csv", "csv", dbParams,
-			 GWEN_DB_FLAGS_DEFAULT, 0, 2000);
+			 GWEN_DB_FLAGS_DEFAULT);
   if (rv) {
     DBG_ERROR(0, "Error writing file");
     return 2;
@@ -413,8 +309,7 @@ int readCSVCountries(const char *fname, GWEN_DB_NODE *db) {
                        "columns/12", "v[11]");
 
   rv=GWEN_DB_ReadFileAs(db, fname, "csv", dbParams,
-			GWEN_PATH_FLAGS_CREATE_GROUP,
-			0, 2000);
+			GWEN_PATH_FLAGS_CREATE_GROUP);
   if (rv) {
     DBG_ERROR(0, "Error reading file");
     return 2;
@@ -604,7 +499,7 @@ int test7(int argc, char **argv) {
   if (rv)
     return rv;
 
-  GWEN_DB_Dump(dbCountries, stderr, 2);
+  GWEN_DB_Dump(dbCountries, 2);
   return 0;
 }
 
@@ -726,7 +621,7 @@ int test8(int argc, char **argv) {
 	}
 	else {
 	  DBG_ERROR(0, "Country \"%s\" has no number", code);
-	  GWEN_DB_Dump(dbT, stderr, 2);
+	  GWEN_DB_Dump(dbT, 2);
 	}
       }
     }
@@ -802,7 +697,7 @@ int test8(int argc, char **argv) {
   }
 
 
-  GWEN_DB_Dump(dbXML, stderr, 2);
+  GWEN_DB_Dump(dbXML, 2);
   return 0;
 }
 
@@ -1113,47 +1008,6 @@ int test13(int argc, char **argv) {
 
 
 
-int test14(int argc, char **argv) {
-  AB_BANKING *ab;
-  int rv;
-  GWEN_BUFFER *buf;
-
-  GWEN_Logger_SetLevel(AQBANKING_LOGDOMAIN, GWEN_LoggerLevel_Error);
-
-  fprintf(stderr, "Creating AB_Banking...\n");
-  ab=AB_Banking_new("abtest", 0, 0);
-
-  fprintf(stderr, "Initializing AB_Banking...\n");
-  rv=AB_Banking_Init(ab);
-  if (rv) {
-    fprintf(stderr, "Could not init AqBanking (%d)\n", rv);
-    return 2;
-  }
-
-  buf=GWEN_Buffer_new(0, 256, 0, 1);
-  rv=AB_Banking_FindWizard(ab, "aqhbci", "qt", buf);
-  if (rv) {
-    fprintf(stderr, "Error: %d\n", rv);
-    return 2;
-  }
-  fprintf(stderr, "Found wizard: %s\n", GWEN_Buffer_GetStart(buf));
-
-  fprintf(stderr, "Deinitializing AB_Banking...\n");
-  rv=AB_Banking_Fini(ab);
-  if (rv) {
-    fprintf(stderr, "Could not deinit AqBanking (%d)\n", rv);
-    return 2;
-  }
-
-  fprintf(stderr, "Freeing AB_Banking...\n");
-  AB_Banking_free(ab);
-
-  fprintf(stderr, "Finished\n");
-  return 0;
-}
-
-
-
 int test15(int argc, char **argv) {
   AB_BANKING *ab;
   int rv;
@@ -1192,9 +1046,7 @@ int test15(int argc, char **argv) {
   rv=GWEN_DBIO_ImportFromFile(dbio, fname,
 			      dbData,
 			      dbParams,
-			      GWEN_PATH_FLAGS_CREATE_GROUP,
-			      0,
-                              2000);
+			      GWEN_PATH_FLAGS_CREATE_GROUP);
   if (rv) {
     fprintf(stderr, "Error on import (%d)\n", rv);
     return 2;
@@ -1210,7 +1062,7 @@ int test15(int argc, char **argv) {
   fprintf(stderr, "Freeing AB_Banking...\n");
   AB_Banking_free(ab);
 
-  GWEN_DB_Dump(dbData, stderr, 2);
+  GWEN_DB_Dump(dbData, 2);
 
   fprintf(stderr, "Finished\n");
   return 0;
@@ -1218,91 +1070,6 @@ int test15(int argc, char **argv) {
 
 
 
-int testMsgEngine(int argc, char **argv) {
-  const char *xmlFile;
-  const char *dataFile;
-  GWEN_XMLNODE *nRoot;
-  GWEN_MSGENGINE *e;
-  int fd;
-  int c;
-  GWEN_BUFFEREDIO *bio;
-  GWEN_DB_NODE *db;
-  GWEN_BUFFER *mbuf;
-
-  if (argc<4) {
-    fprintf(stderr, "Usage: %s msg XMLFILE DATAFILE\n", argv[0]);
-    return 1;
-  }
-
-  xmlFile=argv[2];
-  dataFile=argv[3];
-
-  GWEN_Logger_SetLevel(GWEN_LOGDOMAIN, GWEN_LoggerLevel_Debug);
-  GWEN_Logger_SetLevel(AQBANKING_LOGDOMAIN, GWEN_LoggerLevel_Debug);
-
-  e=AB_MsgEngine_new();
-
-  nRoot=GWEN_XMLNode_new(GWEN_XMLNodeTypeTag, "root");
-  if (GWEN_XML_ReadFile(nRoot, xmlFile,
-                        GWEN_XML_FLAGS_DEFAULT |
-                        GWEN_XML_FLAGS_HANDLE_HEADERS)) {
-    DBG_ERROR(0, "Could not read XML file.\n");
-    return 2;
-  }
-  GWEN_MsgEngine_SetDefinitions(e, nRoot, 1);
-
-
-  fd=open(dataFile, O_RDONLY);
-  if (fd==-1) {
-    DBG_ERROR(0, "Could not open file (%s)", strerror(errno));
-    return 2;
-  }
-
-  bio=GWEN_BufferedIO_File_new(fd);
-  GWEN_BufferedIO_SetReadBuffer(bio, 0, 1024);
-
-  mbuf=GWEN_Buffer_new(0, 1024, 0, 1);
-  db=GWEN_DB_Group_new("transactions");
-
-  while(1) {
-    int err;
-    int rv;
-
-    GWEN_Buffer_Reset(mbuf);
-    c=GWEN_BufferedIO_PeekChar(bio);
-    if (c==GWEN_BUFFEREDIO_CHAR_EOF || c==26)
-      break;
-    else if (c==GWEN_BUFFEREDIO_CHAR_ERROR) {
-      DBG_ERROR(0, "Error reading message");
-      return 2;
-    }
-
-    err=GWEN_BufferedIO_ReadLine2Buffer(bio, mbuf);
-    if (err) {
-      DBG_ERROR_ERR(0, err);
-      return 2;
-    }
-
-    GWEN_Buffer_Rewind(mbuf);
-    rv=GWEN_MsgEngine_ReadMessage(e, "SEG", mbuf, db, 0);
-    if (rv) {
-      GWEN_Buffer_Dump(mbuf, stderr, 4);
-      DBG_ERROR(0, "Error reading message (%d)", rv);
-      return 2;
-    }
-  }
-
-  GWEN_BufferedIO_Close(bio);
-  GWEN_BufferedIO_free(bio);
-
-  GWEN_DB_Dump(db, stdout, 4);
-  DBG_ERROR(0, "Parsing ok.");
-
-  return 0;
-}
-
-
-
 int testDate(int argc, char **argv) {
   GWEN_TIME *ti;
   int y,m,d;
@@ -1335,12 +1102,8 @@ int main(int argc, char **argv) {
 
   if (strcasecmp(cmd, "test1")==0)
     rv=test1(argc, argv);
-  else if (strcasecmp(cmd, "test2")==0)
-    rv=test2(argc, argv);
   else if (strcasecmp(cmd, "test3")==0)
     rv=test3(argc, argv);
-  else if (strcasecmp(cmd, "test4")==0)
-    rv=test4(argc, argv);
   else if (strcasecmp(cmd, "test5")==0)
     rv=test5(argc, argv);
   else if (strcasecmp(cmd, "test6")==0)
@@ -1359,12 +1122,8 @@ int main(int argc, char **argv) {
     rv=test12(argc, argv);
   else if (strcasecmp(cmd, "test13")==0)
     rv=test13(argc, argv);
-  else if (strcasecmp(cmd, "test14")==0)
-    rv=test14(argc, argv);
   else if (strcasecmp(cmd, "test15")==0)
     rv=test15(argc, argv);
-  else if (strcasecmp(cmd, "msg")==0)
-    rv=testMsgEngine(argc, argv);
   else if (strcasecmp(cmd, "date")==0)
     rv=testDate(argc, argv);
   else {
