@@ -1,6 +1,6 @@
 /***************************************************************************
  begin       : Tue May 03 2005
- copyright   : (C) 2005-2010 by Martin Preuss
+ copyright   : (C) 2005-2014 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -16,6 +16,7 @@
 #include <aqbanking/jobgettransactions.h>
 #include <aqbanking/jobgetbalance.h>
 #include <aqbanking/jobgetstandingorders.h>
+#include <aqbanking/jobsepagetstandingorders.h>
 #include <aqbanking/jobgetdatedtransfers.h>
 
 #include <gwenhywfar/text.h>
@@ -43,7 +44,9 @@ int request(AB_BANKING *ab,
   int reqTrans=0;
   int reqBalance=0;
   int reqSto=0;
+  int reqSepaSto=0;
   int reqDT=0;
+  int ignoreUnsupported=0;
   GWEN_TIME *fromTime=0;
   GWEN_TIME *toTime=0;
   AB_JOB_LIST2 *jobList;
@@ -147,6 +150,17 @@ int request(AB_BANKING *ab,
     "Request standing orders",    /* short description */
     "Request standing orders"     /* long description */
   },
+  {
+    0,                            /* flags */
+    GWEN_ArgsType_Int,             /* type */
+    "reqSepaSto",                     /* name */
+    0,                            /* minnum */
+    1,                            /* maxnum */
+    0,                            /* short option */
+    "sepaSto",                    /* long option */
+    "Request SEPA standing orders",    /* short description */
+    "Request SEPA standing orders"     /* long description */
+  },
   {
     0,                            /* flags */
     GWEN_ArgsType_Int,             /* type */
@@ -158,6 +172,17 @@ int request(AB_BANKING *ab,
     "Request dated transfers",    /* short description */
     "Request dated transfers"     /* long description */
   },
+  {
+    0,                
+    GWEN_ArgsType_Int,
+    "ignoreUnsupported",
+    0,  
+    1,  
+    0, 
+    "ignoreUnsupported",
+    "let AqBanking ignore unsupported requests for accounts",
+    "let AqBanking ignore unsupported requests for accounts",
+  },
   {
     GWEN_ARGS_FLAGS_HAS_ARGUMENT, /* flags */
     GWEN_ArgsType_Char,            /* type */
@@ -177,9 +202,10 @@ int request(AB_BANKING *ab,
     1,                            /* maxnum */
     0,                            /* short option */
     "todate",                     /* long option */
-    "Specify the first date for which transactions are wanted (YYYYMMDD)", /* short */
-    "Specify the first date for which transactions are wanted (YYYYMMDD)" /* long */
+    "Specify the last date for which transactions are wanted (YYYYMMDD)", /* short */
+    "Specify the last date for which transactions are wanted (YYYYMMDD)" /* long */
   },
+
   {
     GWEN_ARGS_FLAGS_HELP | GWEN_ARGS_FLAGS_LAST, /* flags */
     GWEN_ArgsType_Int,            /* type */
@@ -215,9 +241,11 @@ int request(AB_BANKING *ab,
     return 0;
   }
 
+  ignoreUnsupported=GWEN_DB_GetIntValue(db, "ignoreUnsupported", 0, 0);
   reqTrans=GWEN_DB_GetIntValue(db, "reqTrans", 0, 0);
   reqBalance=GWEN_DB_GetIntValue(db, "reqBalance", 0, 0);
   reqSto=GWEN_DB_GetIntValue(db, "reqSto", 0, 0);
+  reqSepaSto=GWEN_DB_GetIntValue(db, "reqSepaSto", 0, 0);
   reqDT=GWEN_DB_GetIntValue(db, "reqDT", 0, 0);
   ctxFile=GWEN_DB_GetCharValue(db, "ctxfile", 0, 0);
   s=GWEN_DB_GetCharValue(db, "fromDate", 0, 0);
@@ -247,6 +275,7 @@ int request(AB_BANKING *ab,
     GWEN_Buffer_free(dbuf);
     if (toTime==0) {
       DBG_ERROR(0, "Invalid todate value \"%s\"", s);
+      GWEN_Time_free(fromTime);
       return 1;
     }
   }
@@ -254,12 +283,16 @@ int request(AB_BANKING *ab,
   rv=AB_Banking_Init(ab);
   if (rv) {
     DBG_ERROR(0, "Error on init (%d)", rv);
+    GWEN_Time_free(toTime);
+    GWEN_Time_free(fromTime);
     return 2;
   }
 
   rv=AB_Banking_OnlineInit(ab);
   if (rv) {
     DBG_ERROR(0, "Error on init (%d)", rv);
+    GWEN_Time_free(toTime);
+    GWEN_Time_free(fromTime);
     return 2;
   }
 
@@ -287,7 +320,41 @@ int request(AB_BANKING *ab,
       a=AB_Account_List2Iterator_Data(ait);
       assert(a);
       while(a) {
-        int matches=1;
+	int matches=1;
+        GWEN_BUFFER *accNameBuf;
+
+        accNameBuf=GWEN_Buffer_new(0, 256, 0, 1);
+
+        s=AB_Account_GetBankName(a);
+        if (s) {
+          GWEN_Buffer_AppendString(accNameBuf, " Bank Name: ");
+          GWEN_Buffer_AppendString(accNameBuf, s);
+        }
+
+        s=AB_Account_GetBankCode(a);
+        if (s) {
+          GWEN_Buffer_AppendString(accNameBuf, " Bank Code: ");
+          GWEN_Buffer_AppendString(accNameBuf, s);
+        }
+
+        s=AB_Account_GetAccountName(a);
+        if (s) {
+          GWEN_Buffer_AppendString(accNameBuf, " Account Name: ");
+          GWEN_Buffer_AppendString(accNameBuf, s);
+        }
+
+        s=AB_Account_GetAccountNumber(a);
+        if (s) {
+          GWEN_Buffer_AppendString(accNameBuf, " Account Num: ");
+          GWEN_Buffer_AppendString(accNameBuf, s);
+        }
+
+        s=AB_Account_GetSubAccountId(a);
+        if (s) {
+          GWEN_Buffer_AppendString(accNameBuf, " Account Suffix: ");
+          GWEN_Buffer_AppendString(accNameBuf, s);
+        }
+
 
         if (matches && bankId) {
           s=AB_Account_GetBankCode(a);
@@ -320,84 +387,184 @@ int request(AB_BANKING *ab,
         }
 
         if (matches) {
+
           if (reqTrans) {
             AB_JOB *j;
 
 	    j=AB_JobGetTransactions_new(a);
 	    rv=AB_Job_CheckAvailability(j);
-	    if (rv<0) {
-	      DBG_ERROR(0,
-			"Error requesting transactions for %s/%s: %d",
-			AB_Account_GetBankCode(a),
-			AB_Account_GetAccountNumber(a),
-			rv);
-	      return 3;
+            if (rv>=0) {
+              if (fromTime)
+                AB_JobGetTransactions_SetFromTime(j, fromTime);
+              if (toTime)
+                AB_JobGetTransactions_SetToTime(j, toTime);
+              AB_Job_List2_PushBack(jobList, j);
+              requests++;
+            }
+            else {
+              if (ignoreUnsupported) {
+                DBG_ERROR(0,
+                          "Ignoring transfer request for %s: %d",
+                          GWEN_Buffer_GetStart(accNameBuf),
+                          rv);
+                AB_Job_free(j);
+              }
+              else {
+                DBG_ERROR(0,
+                          "Error requesting transfers for %s: %d",
+                          GWEN_Buffer_GetStart(accNameBuf),
+                          rv);
+                GWEN_Buffer_free(accNameBuf);
+                AB_Account_List2Iterator_free(ait);
+                AB_Account_List2_free(al);
+                AB_Job_List2_FreeAll(jobList);
+                GWEN_Time_free(toTime);
+                GWEN_Time_free(fromTime);
+                return 3;
+              }
 	    }
-            if (fromTime)
-	      AB_JobGetTransactions_SetFromTime(j, fromTime);
-            if (toTime)
-	      AB_JobGetTransactions_SetToTime(j, toTime);
+          }
 
-            AB_Job_List2_PushBack(jobList, j);
-	    requests++;
-	  }
 	  if (reqBalance) {
             AB_JOB *j;
 
 	    j=AB_JobGetBalance_new(a);
 	    rv=AB_Job_CheckAvailability(j);
-	    if (rv<0) {
-	      DBG_ERROR(0,
-			"Error requesting balance for %s/%s: %d",
-			AB_Account_GetBankCode(a),
-			AB_Account_GetAccountNumber(a),
-			rv);
-	      return 3;
+            if (rv>=0) {
+              AB_Job_List2_PushBack(jobList, j);
+              requests++;
+            }
+            else {
+              if (ignoreUnsupported) {
+                DBG_ERROR(0,
+                          "Ignoring balance request for %s: %d",
+                          GWEN_Buffer_GetStart(accNameBuf),
+                          rv);
+                AB_Job_free(j);
+              }
+              else {
+                DBG_ERROR(0,
+                          "Error requesting balance for %s: %d",
+                          GWEN_Buffer_GetStart(accNameBuf),
+                          rv);
+                GWEN_Buffer_free(accNameBuf);
+                AB_Account_List2Iterator_free(ait);
+                AB_Account_List2_free(al);
+                AB_Job_List2_FreeAll(jobList);
+                GWEN_Time_free(toTime);
+                GWEN_Time_free(fromTime);
+                return 3;
+              }
 	    }
-            AB_Job_List2_PushBack(jobList, j);
-            requests++;
           }
           if (reqSto) {
             AB_JOB *j;
 
 	    j=AB_JobGetStandingOrders_new(a);
 	    rv=AB_Job_CheckAvailability(j);
-	    if (rv<0) {
-	      DBG_ERROR(0,
-			"Error requesting standing order for %s/%s: %d",
-			AB_Account_GetBankCode(a),
-			AB_Account_GetAccountNumber(a),
-			rv);
-	      return 3;
+            if (rv>=0) {
+              AB_Job_List2_PushBack(jobList, j);
+              requests++;
+            }
+            else {
+              if (ignoreUnsupported) {
+                DBG_ERROR(0,
+                          "Ignoring standing order request for %s: %d",
+                          GWEN_Buffer_GetStart(accNameBuf),
+                          rv);
+                AB_Job_free(j);
+              }
+              else {
+                DBG_ERROR(0,
+                          "Error requesting standing orders for %s: %d",
+                          GWEN_Buffer_GetStart(accNameBuf),
+                          rv);
+                GWEN_Buffer_free(accNameBuf);
+                AB_Account_List2Iterator_free(ait);
+                AB_Account_List2_free(al);
+                AB_Job_List2_FreeAll(jobList);
+                GWEN_Time_free(toTime);
+                GWEN_Time_free(fromTime);
+                return 3;
+              }
+	    }
+	  }
+          if (reqSepaSto) {
+            AB_JOB *j;
+
+	    j=AB_JobSepaGetStandingOrders_new(a);
+	    rv=AB_Job_CheckAvailability(j);
+            if (rv>=0) {
+              AB_Job_List2_PushBack(jobList, j);
+              requests++;
+            }
+            else {
+              if (ignoreUnsupported) {
+                DBG_ERROR(0,
+                          "Ignoring SEPA standing order request for %s: %d",
+                          GWEN_Buffer_GetStart(accNameBuf),
+                          rv);
+                AB_Job_free(j);
+              }
+              else {
+                DBG_ERROR(0,
+                          "Error requesting SEPA standing orders for %s: %d",
+                          GWEN_Buffer_GetStart(accNameBuf),
+                          rv);
+                GWEN_Buffer_free(accNameBuf);
+                AB_Account_List2Iterator_free(ait);
+                AB_Account_List2_free(al);
+                AB_Job_List2_FreeAll(jobList);
+                GWEN_Time_free(toTime);
+                GWEN_Time_free(fromTime);
+                return 3;
+              }
 	    }
-            AB_Job_List2_PushBack(jobList, j);
-	    requests++;
 	  }
 	  if (reqDT) {
             AB_JOB *j;
 
 	    j=AB_JobGetDatedTransfers_new(a);
 	    rv=AB_Job_CheckAvailability(j);
-	    if (rv<0) {
-	      DBG_ERROR(0,
-			"Error requesting dated transfers for %s/%s: %d",
-			AB_Account_GetBankCode(a),
-			AB_Account_GetAccountNumber(a),
-			rv);
-	      return 3;
+            if (rv>=0) {
+              AB_Job_List2_PushBack(jobList, j);
+              requests++;
+            }
+            else {
+              if (ignoreUnsupported) {
+                DBG_ERROR(0,
+                          "Ignoring dated transfers request for %s: %d",
+                          GWEN_Buffer_GetStart(accNameBuf),
+                          rv);
+                AB_Job_free(j);
+              }
+              else {
+                DBG_ERROR(0,
+                          "Error requesting dated transfers for %s: %d",
+                          GWEN_Buffer_GetStart(accNameBuf),
+                          rv);
+                GWEN_Buffer_free(accNameBuf);
+                AB_Account_List2Iterator_free(ait);
+                AB_Account_List2_free(al);
+                AB_Job_List2_FreeAll(jobList);
+                GWEN_Time_free(toTime);
+                GWEN_Time_free(fromTime);
+                return 3;
+              }
 	    }
-            AB_Job_List2_PushBack(jobList, j);
-	    requests++;
-	  }
+          }
 	}
 
+        GWEN_Buffer_free(accNameBuf);
+
         a=AB_Account_List2Iterator_Next(ait);
       }
       AB_Account_List2Iterator_free(ait);
-      GWEN_Time_free(toTime);
-      GWEN_Time_free(fromTime);
     }
   }
+  AB_Account_List2_free(al);
+  GWEN_Time_free(toTime);
+  GWEN_Time_free(fromTime);
 
   if (requests) {
     AB_IMEXPORTER_CONTEXT *ctx;
@@ -405,12 +572,15 @@ int request(AB_BANKING *ab,
     DBG_INFO(0, "%d requests created", requests);
     ctx=AB_ImExporterContext_new();
     rv=AB_Banking_ExecuteJobs(ab, jobList, ctx);
+    AB_Job_List2_FreeAll(jobList);
     if (rv) {
       fprintf(stderr, "Error on executeQueue (%d)\n", rv);
+      AB_ImExporterContext_free(ctx);
       return 3;
     }
 
     rv=writeContext(ctxFile, ctx);
+    AB_ImExporterContext_free(ctx);
     if (rv<0) {
       DBG_ERROR(0, "Error writing context file (%d)", rv);
       AB_Banking_OnlineFini(ab);
@@ -420,6 +590,7 @@ int request(AB_BANKING *ab,
   }
   else {
     DBG_ERROR(0, "No requests created");
+    AB_Job_List2_FreeAll(jobList);
     AB_Banking_OnlineFini(ab);
     AB_Banking_Fini(ab);
     return 4;
