@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Tue May 03 2005
  copyright   : (C) 2005 by Martin Preuss
  email       : martin@libchipcard.de
@@ -16,14 +13,14 @@
  * This tutorial shows how to use jobs in AqBanking.                       *
  * In this example we retrieve transaction statements for a given account. *
  *                                                                         *
- * You must either choose a frontend to be used with AqBanking or create   *
- * one yourself by implementing the user interface callbacks of AqBanking. *
+ * You must either choose a GUI implementation to be used with AqBanking   *
+ * or create one yourself by implementing the user interface callbacks of  *
+ * LibGwenhywfar.                                                          *
  *                                                                         *
- * However, for simplicity reasons we use the console frontend CBanking    *
+ * However, for simplicity reasons we use the console GUI implementation   *
  * which implements these callbacks for you.                               *
  *                                                                         *
- * There are other frontends, e.g. G2Banking for GTK2/Gnome, QBanking for  *
- * QT3 or KDE3 or KBanking for KDE3.                                       *
+ * There are other GUI implementations, e.g. for GTK2, QT3, QT4 and FOX16. *
  ***************************************************************************/
 
 
@@ -65,7 +62,7 @@ int main(int argc, char **argv) {
   /* This function loads the settings file of AqBanking so the users and
    * accounts become available after this function successfully returns.
    */
-  rv=AB_Banking_OnlineInit(ab, 0);
+  rv=AB_Banking_OnlineInit(ab);
   if (rv) {
     fprintf(stderr, "Error on init of online modules (%d)\n", rv);
     return 2;
@@ -77,7 +74,8 @@ int main(int argc, char **argv) {
                            "aqhbci", /* backend name */
                            "de",     /* two-char ISO country code */
                            "200*",   /* bank code (with wildcard) */
-                           "*");     /* account number (wildcard) */
+                           "*",      /* account number (wildcard) */
+                           "*");     /* sub account id (Unterkontomerkmal) */
   if (a) {
     AB_JOB_LIST2 *jl;
     AB_JOB *j;
@@ -92,7 +90,7 @@ int main(int argc, char **argv) {
      * is available with the given account.
      * If the job is available then 0 is returned, otherwise the error code
      * might give you a hint why the job is not supported. */
-    rv=AB_Job_CheckAvailability(j, 0);
+    rv=AB_Job_CheckAvailability(j);
     if (rv) {
       fprintf(stderr, "Job is not available (%d)\n", rv);
       return 2;
@@ -119,7 +117,7 @@ int main(int argc, char **argv) {
      * It only returns an error code (!=0) if there has been a problem
      * sending the jobs.
      */
-    rv=AB_Banking_ExecuteJobs(ab, jl, ctx, 0);
+    rv=AB_Banking_ExecuteJobs(ab, jl, ctx);
     if (rv) {
       fprintf(stderr, "Error on executeQueue (%d)\n", rv);
       return 2;
@@ -149,7 +147,7 @@ int main(int argc, char **argv) {
             else
               purpose="";
 
-            fprintf(stderr, " %-32s (%.2lf %s)\n",
+            fprintf(stderr, " %-32s (%.2f %s)\n",
                     purpose,
 		    AB_Value_GetValueAsDouble(v),
                     AB_Value_GetCurrency(v));
@@ -169,7 +167,7 @@ int main(int argc, char **argv) {
   /* This function MUST be called in order to let AqBanking save the changes
    * to the users and accounts (like they occur after executing jobs).
    */
-  rv=AB_Banking_OnlineFini(ab, 0);
+  rv=AB_Banking_OnlineFini(ab);
   if (rv) {
     fprintf(stderr, "ERROR: Error on deinit online modules (%d)\n", rv);
     return 3;
